"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class AdNetworkTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _AdNetworkType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[AdNetworkType.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = AdNetworkTypeEnum.AdNetworkType.V(0)
        UNKNOWN = AdNetworkTypeEnum.AdNetworkType.V(1)
        SEARCH = AdNetworkTypeEnum.AdNetworkType.V(2)
        SEARCH_PARTNERS = AdNetworkTypeEnum.AdNetworkType.V(3)
        CONTENT = AdNetworkTypeEnum.AdNetworkType.V(4)
        YOUTUBE_SEARCH = AdNetworkTypeEnum.AdNetworkType.V(5)
        YOUTUBE_WATCH = AdNetworkTypeEnum.AdNetworkType.V(6)
        MIXED = AdNetworkTypeEnum.AdNetworkType.V(7)
    class AdNetworkType(metaclass=_AdNetworkType):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = AdNetworkTypeEnum.AdNetworkType.V(0)
    UNKNOWN = AdNetworkTypeEnum.AdNetworkType.V(1)
    SEARCH = AdNetworkTypeEnum.AdNetworkType.V(2)
    SEARCH_PARTNERS = AdNetworkTypeEnum.AdNetworkType.V(3)
    CONTENT = AdNetworkTypeEnum.AdNetworkType.V(4)
    YOUTUBE_SEARCH = AdNetworkTypeEnum.AdNetworkType.V(5)
    YOUTUBE_WATCH = AdNetworkTypeEnum.AdNetworkType.V(6)
    MIXED = AdNetworkTypeEnum.AdNetworkType.V(7)
    def __init__(
        self,
    ) -> None: ...

global___AdNetworkTypeEnum = AdNetworkTypeEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class SlotEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _Slot(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Slot.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = SlotEnum.Slot.V(0)
        UNKNOWN = SlotEnum.Slot.V(1)
        SEARCH_SIDE = SlotEnum.Slot.V(2)
        SEARCH_TOP = SlotEnum.Slot.V(3)
        SEARCH_OTHER = SlotEnum.Slot.V(4)
        CONTENT = SlotEnum.Slot.V(5)
        SEARCH_PARTNER_TOP = SlotEnum.Slot.V(6)
        SEARCH_PARTNER_OTHER = SlotEnum.Slot.V(7)
        MIXED = SlotEnum.Slot.V(8)
    class Slot(metaclass=_Slot):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = SlotEnum.Slot.V(0)
    UNKNOWN = SlotEnum.Slot.V(1)
    SEARCH_SIDE = SlotEnum.Slot.V(2)
    SEARCH_TOP = SlotEnum.Slot.V(3)
    SEARCH_OTHER = SlotEnum.Slot.V(4)
    CONTENT = SlotEnum.Slot.V(5)
    SEARCH_PARTNER_TOP = SlotEnum.Slot.V(6)
    SEARCH_PARTNER_OTHER = SlotEnum.Slot.V(7)
    MIXED = SlotEnum.Slot.V(8)
    def __init__(
        self,
    ) -> None: ...

global___SlotEnum = SlotEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v6.proto.common.custom_parameter_pb2
import google.ads.google_ads.v6.proto.common.feed_common_pb2
import google.ads.google_ads.v6.proto.common.policy_pb2
import google.ads.google_ads.v6.proto.enums.feed_item_quality_approval_status_pb2
import google.ads.google_ads.v6.proto.enums.feed_item_quality_disapproval_reason_pb2
import google.ads.google_ads.v6.proto.enums.feed_item_status_pb2
import google.ads.google_ads.v6.proto.enums.feed_item_validation_status_pb2
import google.ads.google_ads.v6.proto.enums.geo_targeting_restriction_pb2
import google.ads.google_ads.v6.proto.enums.placeholder_type_pb2
import google.ads.google_ads.v6.proto.enums.policy_approval_status_pb2
import google.ads.google_ads.v6.proto.enums.policy_review_status_pb2
import google.ads.google_ads.v6.proto.errors.feed_item_validation_error_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class FeedItem(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    FEED_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    START_DATE_TIME_FIELD_NUMBER: builtins.int
    END_DATE_TIME_FIELD_NUMBER: builtins.int
    ATTRIBUTE_VALUES_FIELD_NUMBER: builtins.int
    GEO_TARGETING_RESTRICTION_FIELD_NUMBER: builtins.int
    URL_CUSTOM_PARAMETERS_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    POLICY_INFOS_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    feed: typing.Text = ...
    id: builtins.int = ...
    start_date_time: typing.Text = ...
    end_date_time: typing.Text = ...
    geo_targeting_restriction: google.ads.google_ads.v6.proto.enums.geo_targeting_restriction_pb2.GeoTargetingRestrictionEnum.GeoTargetingRestriction.V = (
        ...
    )
    status: google.ads.google_ads.v6.proto.enums.feed_item_status_pb2.FeedItemStatusEnum.FeedItemStatus.V = (
        ...
    )
    @property
    def attribute_values(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___FeedItemAttributeValue
    ]: ...
    @property
    def url_custom_parameters(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.ads.google_ads.v6.proto.common.custom_parameter_pb2.CustomParameter
    ]: ...
    @property
    def policy_infos(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___FeedItemPlaceholderPolicyInfo
    ]: ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        feed: typing.Text = ...,
        id: builtins.int = ...,
        start_date_time: typing.Text = ...,
        end_date_time: typing.Text = ...,
        attribute_values: typing.Optional[
            typing.Iterable[global___FeedItemAttributeValue]
        ] = ...,
        geo_targeting_restriction: google.ads.google_ads.v6.proto.enums.geo_targeting_restriction_pb2.GeoTargetingRestrictionEnum.GeoTargetingRestriction.V = ...,
        url_custom_parameters: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v6.proto.common.custom_parameter_pb2.CustomParameter
            ]
        ] = ...,
        status: google.ads.google_ads.v6.proto.enums.feed_item_status_pb2.FeedItemStatusEnum.FeedItemStatus.V = ...,
        policy_infos: typing.Optional[
            typing.Iterable[global___FeedItemPlaceholderPolicyInfo]
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_end_date_time",
            b"_end_date_time",
            "_feed",
            b"_feed",
            "_id",
            b"_id",
            "_start_date_time",
            b"_start_date_time",
            "end_date_time",
            b"end_date_time",
            "feed",
            b"feed",
            "id",
            b"id",
            "start_date_time",
            b"start_date_time",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_end_date_time",
            b"_end_date_time",
            "_feed",
            b"_feed",
            "_id",
            b"_id",
            "_start_date_time",
            b"_start_date_time",
            "attribute_values",
            b"attribute_values",
            "end_date_time",
            b"end_date_time",
            "feed",
            b"feed",
            "geo_targeting_restriction",
            b"geo_targeting_restriction",
            "id",
            b"id",
            "policy_infos",
            b"policy_infos",
            "resource_name",
            b"resource_name",
            "start_date_time",
            b"start_date_time",
            "status",
            b"status",
            "url_custom_parameters",
            b"url_custom_parameters",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_end_date_time", b"_end_date_time"],
    ) -> typing_extensions.Literal["end_date_time"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_feed", b"_feed"]
    ) -> typing_extensions.Literal["feed"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_id", b"_id"]
    ) -> typing_extensions.Literal["id"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_start_date_time", b"_start_date_time"],
    ) -> typing_extensions.Literal["start_date_time"]: ...

global___FeedItem = FeedItem

class FeedItemAttributeValue(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    FEED_ATTRIBUTE_ID_FIELD_NUMBER: builtins.int
    INTEGER_VALUE_FIELD_NUMBER: builtins.int
    BOOLEAN_VALUE_FIELD_NUMBER: builtins.int
    STRING_VALUE_FIELD_NUMBER: builtins.int
    DOUBLE_VALUE_FIELD_NUMBER: builtins.int
    PRICE_VALUE_FIELD_NUMBER: builtins.int
    INTEGER_VALUES_FIELD_NUMBER: builtins.int
    BOOLEAN_VALUES_FIELD_NUMBER: builtins.int
    STRING_VALUES_FIELD_NUMBER: builtins.int
    DOUBLE_VALUES_FIELD_NUMBER: builtins.int
    feed_attribute_id: builtins.int = ...
    integer_value: builtins.int = ...
    boolean_value: builtins.bool = ...
    string_value: typing.Text = ...
    double_value: builtins.float = ...
    integer_values: google.protobuf.internal.containers.RepeatedScalarFieldContainer[
        builtins.int
    ] = ...
    boolean_values: google.protobuf.internal.containers.RepeatedScalarFieldContainer[
        builtins.bool
    ] = ...
    string_values: google.protobuf.internal.containers.RepeatedScalarFieldContainer[
        typing.Text
    ] = ...
    double_values: google.protobuf.internal.containers.RepeatedScalarFieldContainer[
        builtins.float
    ] = ...
    @property
    def price_value(
        self,
    ) -> google.ads.google_ads.v6.proto.common.feed_common_pb2.Money: ...
    def __init__(
        self,
        *,
        feed_attribute_id: builtins.int = ...,
        integer_value: builtins.int = ...,
        boolean_value: builtins.bool = ...,
        string_value: typing.Text = ...,
        double_value: builtins.float = ...,
        price_value: typing.Optional[
            google.ads.google_ads.v6.proto.common.feed_common_pb2.Money
        ] = ...,
        integer_values: typing.Optional[typing.Iterable[builtins.int]] = ...,
        boolean_values: typing.Optional[typing.Iterable[builtins.bool]] = ...,
        string_values: typing.Optional[typing.Iterable[typing.Text]] = ...,
        double_values: typing.Optional[typing.Iterable[builtins.float]] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_boolean_value",
            b"_boolean_value",
            "_double_value",
            b"_double_value",
            "_feed_attribute_id",
            b"_feed_attribute_id",
            "_integer_value",
            b"_integer_value",
            "_string_value",
            b"_string_value",
            "boolean_value",
            b"boolean_value",
            "double_value",
            b"double_value",
            "feed_attribute_id",
            b"feed_attribute_id",
            "integer_value",
            b"integer_value",
            "price_value",
            b"price_value",
            "string_value",
            b"string_value",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_boolean_value",
            b"_boolean_value",
            "_double_value",
            b"_double_value",
            "_feed_attribute_id",
            b"_feed_attribute_id",
            "_integer_value",
            b"_integer_value",
            "_string_value",
            b"_string_value",
            "boolean_value",
            b"boolean_value",
            "boolean_values",
            b"boolean_values",
            "double_value",
            b"double_value",
            "double_values",
            b"double_values",
            "feed_attribute_id",
            b"feed_attribute_id",
            "integer_value",
            b"integer_value",
            "integer_values",
            b"integer_values",
            "price_value",
            b"price_value",
            "string_value",
            b"string_value",
            "string_values",
            b"string_values",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_boolean_value", b"_boolean_value"],
    ) -> typing_extensions.Literal["boolean_value"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_double_value", b"_double_value"]
    ) -> typing_extensions.Literal["double_value"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_feed_attribute_id", b"_feed_attribute_id"
        ],
    ) -> typing_extensions.Literal["feed_attribute_id"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_integer_value", b"_integer_value"],
    ) -> typing_extensions.Literal["integer_value"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_string_value", b"_string_value"]
    ) -> typing_extensions.Literal["string_value"]: ...

global___FeedItemAttributeValue = FeedItemAttributeValue

class FeedItemPlaceholderPolicyInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PLACEHOLDER_TYPE_ENUM_FIELD_NUMBER: builtins.int
    FEED_MAPPING_RESOURCE_NAME_FIELD_NUMBER: builtins.int
    REVIEW_STATUS_FIELD_NUMBER: builtins.int
    APPROVAL_STATUS_FIELD_NUMBER: builtins.int
    POLICY_TOPIC_ENTRIES_FIELD_NUMBER: builtins.int
    VALIDATION_STATUS_FIELD_NUMBER: builtins.int
    VALIDATION_ERRORS_FIELD_NUMBER: builtins.int
    QUALITY_APPROVAL_STATUS_FIELD_NUMBER: builtins.int
    QUALITY_DISAPPROVAL_REASONS_FIELD_NUMBER: builtins.int
    placeholder_type_enum: google.ads.google_ads.v6.proto.enums.placeholder_type_pb2.PlaceholderTypeEnum.PlaceholderType.V = (
        ...
    )
    feed_mapping_resource_name: typing.Text = ...
    review_status: google.ads.google_ads.v6.proto.enums.policy_review_status_pb2.PolicyReviewStatusEnum.PolicyReviewStatus.V = (
        ...
    )
    approval_status: google.ads.google_ads.v6.proto.enums.policy_approval_status_pb2.PolicyApprovalStatusEnum.PolicyApprovalStatus.V = (
        ...
    )
    validation_status: google.ads.google_ads.v6.proto.enums.feed_item_validation_status_pb2.FeedItemValidationStatusEnum.FeedItemValidationStatus.V = (
        ...
    )
    quality_approval_status: google.ads.google_ads.v6.proto.enums.feed_item_quality_approval_status_pb2.FeedItemQualityApprovalStatusEnum.FeedItemQualityApprovalStatus.V = (
        ...
    )
    quality_disapproval_reasons: google.protobuf.internal.containers.RepeatedScalarFieldContainer[
        google.ads.google_ads.v6.proto.enums.feed_item_quality_disapproval_reason_pb2.FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason.V
    ] = ...
    @property
    def policy_topic_entries(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.ads.google_ads.v6.proto.common.policy_pb2.PolicyTopicEntry
    ]: ...
    @property
    def validation_errors(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___FeedItemValidationError
    ]: ...
    def __init__(
        self,
        *,
        placeholder_type_enum: google.ads.google_ads.v6.proto.enums.placeholder_type_pb2.PlaceholderTypeEnum.PlaceholderType.V = ...,
        feed_mapping_resource_name: typing.Text = ...,
        review_status: google.ads.google_ads.v6.proto.enums.policy_review_status_pb2.PolicyReviewStatusEnum.PolicyReviewStatus.V = ...,
        approval_status: google.ads.google_ads.v6.proto.enums.policy_approval_status_pb2.PolicyApprovalStatusEnum.PolicyApprovalStatus.V = ...,
        policy_topic_entries: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v6.proto.common.policy_pb2.PolicyTopicEntry
            ]
        ] = ...,
        validation_status: google.ads.google_ads.v6.proto.enums.feed_item_validation_status_pb2.FeedItemValidationStatusEnum.FeedItemValidationStatus.V = ...,
        validation_errors: typing.Optional[
            typing.Iterable[global___FeedItemValidationError]
        ] = ...,
        quality_approval_status: google.ads.google_ads.v6.proto.enums.feed_item_quality_approval_status_pb2.FeedItemQualityApprovalStatusEnum.FeedItemQualityApprovalStatus.V = ...,
        quality_disapproval_reasons: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v6.proto.enums.feed_item_quality_disapproval_reason_pb2.FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason.V
            ]
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_feed_mapping_resource_name",
            b"_feed_mapping_resource_name",
            "feed_mapping_resource_name",
            b"feed_mapping_resource_name",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_feed_mapping_resource_name",
            b"_feed_mapping_resource_name",
            "approval_status",
            b"approval_status",
            "feed_mapping_resource_name",
            b"feed_mapping_resource_name",
            "placeholder_type_enum",
            b"placeholder_type_enum",
            "policy_topic_entries",
            b"policy_topic_entries",
            "quality_approval_status",
            b"quality_approval_status",
            "quality_disapproval_reasons",
            b"quality_disapproval_reasons",
            "review_status",
            b"review_status",
            "validation_errors",
            b"validation_errors",
            "validation_status",
            b"validation_status",
        ],
    ) -> None: ...
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_feed_mapping_resource_name", b"_feed_mapping_resource_name"
        ],
    ) -> typing_extensions.Literal["feed_mapping_resource_name"]: ...

global___FeedItemPlaceholderPolicyInfo = FeedItemPlaceholderPolicyInfo

class FeedItemValidationError(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    VALIDATION_ERROR_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    FEED_ATTRIBUTE_IDS_FIELD_NUMBER: builtins.int
    EXTRA_INFO_FIELD_NUMBER: builtins.int
    validation_error: google.ads.google_ads.v6.proto.errors.feed_item_validation_error_pb2.FeedItemValidationErrorEnum.FeedItemValidationError.V = (
        ...
    )
    description: typing.Text = ...
    feed_attribute_ids: google.protobuf.internal.containers.RepeatedScalarFieldContainer[
        builtins.int
    ] = ...
    extra_info: typing.Text = ...
    def __init__(
        self,
        *,
        validation_error: google.ads.google_ads.v6.proto.errors.feed_item_validation_error_pb2.FeedItemValidationErrorEnum.FeedItemValidationError.V = ...,
        description: typing.Text = ...,
        feed_attribute_ids: typing.Optional[typing.Iterable[builtins.int]] = ...,
        extra_info: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_description",
            b"_description",
            "_extra_info",
            b"_extra_info",
            "description",
            b"description",
            "extra_info",
            b"extra_info",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_description",
            b"_description",
            "_extra_info",
            b"_extra_info",
            "description",
            b"description",
            "extra_info",
            b"extra_info",
            "feed_attribute_ids",
            b"feed_attribute_ids",
            "validation_error",
            b"validation_error",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_description", b"_description"]
    ) -> typing_extensions.Literal["description"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_extra_info", b"_extra_info"]
    ) -> typing_extensions.Literal["extra_info"]: ...

global___FeedItemValidationError = FeedItemValidationError



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class FeedErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _FeedError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[FeedError.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = FeedErrorEnum.FeedError.V(0)
        UNKNOWN = FeedErrorEnum.FeedError.V(1)
        ATTRIBUTE_NAMES_NOT_UNIQUE = FeedErrorEnum.FeedError.V(2)
        ATTRIBUTES_DO_NOT_MATCH_EXISTING_ATTRIBUTES = FeedErrorEnum.FeedError.V(3)
        CANNOT_SPECIFY_USER_ORIGIN_FOR_SYSTEM_FEED = FeedErrorEnum.FeedError.V(4)
        CANNOT_SPECIFY_GOOGLE_ORIGIN_FOR_NON_SYSTEM_FEED = FeedErrorEnum.FeedError.V(5)
        CANNOT_SPECIFY_FEED_ATTRIBUTES_FOR_SYSTEM_FEED = FeedErrorEnum.FeedError.V(6)
        CANNOT_UPDATE_FEED_ATTRIBUTES_WITH_ORIGIN_GOOGLE = FeedErrorEnum.FeedError.V(7)
        FEED_REMOVED = FeedErrorEnum.FeedError.V(8)
        INVALID_ORIGIN_VALUE = FeedErrorEnum.FeedError.V(9)
        FEED_ORIGIN_IS_NOT_USER = FeedErrorEnum.FeedError.V(10)
        INVALID_AUTH_TOKEN_FOR_EMAIL = FeedErrorEnum.FeedError.V(11)
        INVALID_EMAIL = FeedErrorEnum.FeedError.V(12)
        DUPLICATE_FEED_NAME = FeedErrorEnum.FeedError.V(13)
        INVALID_FEED_NAME = FeedErrorEnum.FeedError.V(14)
        MISSING_OAUTH_INFO = FeedErrorEnum.FeedError.V(15)
        NEW_ATTRIBUTE_CANNOT_BE_PART_OF_UNIQUE_KEY = FeedErrorEnum.FeedError.V(16)
        TOO_MANY_ATTRIBUTES = FeedErrorEnum.FeedError.V(17)
        INVALID_BUSINESS_ACCOUNT = FeedErrorEnum.FeedError.V(18)
        BUSINESS_ACCOUNT_CANNOT_ACCESS_LOCATION_ACCOUNT = FeedErrorEnum.FeedError.V(19)
        INVALID_AFFILIATE_CHAIN_ID = FeedErrorEnum.FeedError.V(20)
        DUPLICATE_SYSTEM_FEED = FeedErrorEnum.FeedError.V(21)
        GMB_ACCESS_ERROR = FeedErrorEnum.FeedError.V(22)
        CANNOT_HAVE_LOCATION_AND_AFFILIATE_LOCATION_FEEDS = FeedErrorEnum.FeedError.V(
            23
        )
    class FeedError(metaclass=_FeedError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = FeedErrorEnum.FeedError.V(0)
    UNKNOWN = FeedErrorEnum.FeedError.V(1)
    ATTRIBUTE_NAMES_NOT_UNIQUE = FeedErrorEnum.FeedError.V(2)
    ATTRIBUTES_DO_NOT_MATCH_EXISTING_ATTRIBUTES = FeedErrorEnum.FeedError.V(3)
    CANNOT_SPECIFY_USER_ORIGIN_FOR_SYSTEM_FEED = FeedErrorEnum.FeedError.V(4)
    CANNOT_SPECIFY_GOOGLE_ORIGIN_FOR_NON_SYSTEM_FEED = FeedErrorEnum.FeedError.V(5)
    CANNOT_SPECIFY_FEED_ATTRIBUTES_FOR_SYSTEM_FEED = FeedErrorEnum.FeedError.V(6)
    CANNOT_UPDATE_FEED_ATTRIBUTES_WITH_ORIGIN_GOOGLE = FeedErrorEnum.FeedError.V(7)
    FEED_REMOVED = FeedErrorEnum.FeedError.V(8)
    INVALID_ORIGIN_VALUE = FeedErrorEnum.FeedError.V(9)
    FEED_ORIGIN_IS_NOT_USER = FeedErrorEnum.FeedError.V(10)
    INVALID_AUTH_TOKEN_FOR_EMAIL = FeedErrorEnum.FeedError.V(11)
    INVALID_EMAIL = FeedErrorEnum.FeedError.V(12)
    DUPLICATE_FEED_NAME = FeedErrorEnum.FeedError.V(13)
    INVALID_FEED_NAME = FeedErrorEnum.FeedError.V(14)
    MISSING_OAUTH_INFO = FeedErrorEnum.FeedError.V(15)
    NEW_ATTRIBUTE_CANNOT_BE_PART_OF_UNIQUE_KEY = FeedErrorEnum.FeedError.V(16)
    TOO_MANY_ATTRIBUTES = FeedErrorEnum.FeedError.V(17)
    INVALID_BUSINESS_ACCOUNT = FeedErrorEnum.FeedError.V(18)
    BUSINESS_ACCOUNT_CANNOT_ACCESS_LOCATION_ACCOUNT = FeedErrorEnum.FeedError.V(19)
    INVALID_AFFILIATE_CHAIN_ID = FeedErrorEnum.FeedError.V(20)
    DUPLICATE_SYSTEM_FEED = FeedErrorEnum.FeedError.V(21)
    GMB_ACCESS_ERROR = FeedErrorEnum.FeedError.V(22)
    CANNOT_HAVE_LOCATION_AND_AFFILIATE_LOCATION_FEEDS = FeedErrorEnum.FeedError.V(23)
    def __init__(
        self,
    ) -> None: ...

global___FeedErrorEnum = FeedErrorEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class MultiplierErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _MultiplierError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[MultiplierError.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = MultiplierErrorEnum.MultiplierError.V(0)
        UNKNOWN = MultiplierErrorEnum.MultiplierError.V(1)
        MULTIPLIER_TOO_HIGH = MultiplierErrorEnum.MultiplierError.V(2)
        MULTIPLIER_TOO_LOW = MultiplierErrorEnum.MultiplierError.V(3)
        TOO_MANY_FRACTIONAL_DIGITS = MultiplierErrorEnum.MultiplierError.V(4)
        MULTIPLIER_NOT_ALLOWED_FOR_BIDDING_STRATEGY = (
            MultiplierErrorEnum.MultiplierError.V(5)
        )
        MULTIPLIER_NOT_ALLOWED_WHEN_BASE_BID_IS_MISSING = (
            MultiplierErrorEnum.MultiplierError.V(6)
        )
        NO_MULTIPLIER_SPECIFIED = MultiplierErrorEnum.MultiplierError.V(7)
        MULTIPLIER_CAUSES_BID_TO_EXCEED_DAILY_BUDGET = (
            MultiplierErrorEnum.MultiplierError.V(8)
        )
        MULTIPLIER_CAUSES_BID_TO_EXCEED_MONTHLY_BUDGET = (
            MultiplierErrorEnum.MultiplierError.V(9)
        )
        MULTIPLIER_CAUSES_BID_TO_EXCEED_CUSTOM_BUDGET = (
            MultiplierErrorEnum.MultiplierError.V(10)
        )
        MULTIPLIER_CAUSES_BID_TO_EXCEED_MAX_ALLOWED_BID = (
            MultiplierErrorEnum.MultiplierError.V(11)
        )
        BID_LESS_THAN_MIN_ALLOWED_BID_WITH_MULTIPLIER = (
            MultiplierErrorEnum.MultiplierError.V(12)
        )
        MULTIPLIER_AND_BIDDING_STRATEGY_TYPE_MISMATCH = (
            MultiplierErrorEnum.MultiplierError.V(13)
        )
    class MultiplierError(metaclass=_MultiplierError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = MultiplierErrorEnum.MultiplierError.V(0)
    UNKNOWN = MultiplierErrorEnum.MultiplierError.V(1)
    MULTIPLIER_TOO_HIGH = MultiplierErrorEnum.MultiplierError.V(2)
    MULTIPLIER_TOO_LOW = MultiplierErrorEnum.MultiplierError.V(3)
    TOO_MANY_FRACTIONAL_DIGITS = MultiplierErrorEnum.MultiplierError.V(4)
    MULTIPLIER_NOT_ALLOWED_FOR_BIDDING_STRATEGY = MultiplierErrorEnum.MultiplierError.V(
        5
    )
    MULTIPLIER_NOT_ALLOWED_WHEN_BASE_BID_IS_MISSING = (
        MultiplierErrorEnum.MultiplierError.V(6)
    )
    NO_MULTIPLIER_SPECIFIED = MultiplierErrorEnum.MultiplierError.V(7)
    MULTIPLIER_CAUSES_BID_TO_EXCEED_DAILY_BUDGET = (
        MultiplierErrorEnum.MultiplierError.V(8)
    )
    MULTIPLIER_CAUSES_BID_TO_EXCEED_MONTHLY_BUDGET = (
        MultiplierErrorEnum.MultiplierError.V(9)
    )
    MULTIPLIER_CAUSES_BID_TO_EXCEED_CUSTOM_BUDGET = (
        MultiplierErrorEnum.MultiplierError.V(10)
    )
    MULTIPLIER_CAUSES_BID_TO_EXCEED_MAX_ALLOWED_BID = (
        MultiplierErrorEnum.MultiplierError.V(11)
    )
    BID_LESS_THAN_MIN_ALLOWED_BID_WITH_MULTIPLIER = (
        MultiplierErrorEnum.MultiplierError.V(12)
    )
    MULTIPLIER_AND_BIDDING_STRATEGY_TYPE_MISMATCH = (
        MultiplierErrorEnum.MultiplierError.V(13)
    )
    def __init__(
        self,
    ) -> None: ...

global___MultiplierErrorEnum = MultiplierErrorEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class ChangeClientTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _ChangeClientType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ChangeClientType.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = ChangeClientTypeEnum.ChangeClientType.V(0)
        UNKNOWN = ChangeClientTypeEnum.ChangeClientType.V(1)
        GOOGLE_ADS_WEB_CLIENT = ChangeClientTypeEnum.ChangeClientType.V(2)
        GOOGLE_ADS_AUTOMATED_RULE = ChangeClientTypeEnum.ChangeClientType.V(3)
        GOOGLE_ADS_SCRIPTS = ChangeClientTypeEnum.ChangeClientType.V(4)
        GOOGLE_ADS_BULK_UPLOAD = ChangeClientTypeEnum.ChangeClientType.V(5)
        GOOGLE_ADS_API = ChangeClientTypeEnum.ChangeClientType.V(6)
        GOOGLE_ADS_EDITOR = ChangeClientTypeEnum.ChangeClientType.V(7)
        GOOGLE_ADS_MOBILE_APP = ChangeClientTypeEnum.ChangeClientType.V(8)
        GOOGLE_ADS_RECOMMENDATIONS = ChangeClientTypeEnum.ChangeClientType.V(9)
        SEARCH_ADS_360_SYNC = ChangeClientTypeEnum.ChangeClientType.V(10)
        SEARCH_ADS_360_POST = ChangeClientTypeEnum.ChangeClientType.V(11)
        INTERNAL_TOOL = ChangeClientTypeEnum.ChangeClientType.V(12)
        OTHER = ChangeClientTypeEnum.ChangeClientType.V(13)
    class ChangeClientType(metaclass=_ChangeClientType):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = ChangeClientTypeEnum.ChangeClientType.V(0)
    UNKNOWN = ChangeClientTypeEnum.ChangeClientType.V(1)
    GOOGLE_ADS_WEB_CLIENT = ChangeClientTypeEnum.ChangeClientType.V(2)
    GOOGLE_ADS_AUTOMATED_RULE = ChangeClientTypeEnum.ChangeClientType.V(3)
    GOOGLE_ADS_SCRIPTS = ChangeClientTypeEnum.ChangeClientType.V(4)
    GOOGLE_ADS_BULK_UPLOAD = ChangeClientTypeEnum.ChangeClientType.V(5)
    GOOGLE_ADS_API = ChangeClientTypeEnum.ChangeClientType.V(6)
    GOOGLE_ADS_EDITOR = ChangeClientTypeEnum.ChangeClientType.V(7)
    GOOGLE_ADS_MOBILE_APP = ChangeClientTypeEnum.ChangeClientType.V(8)
    GOOGLE_ADS_RECOMMENDATIONS = ChangeClientTypeEnum.ChangeClientType.V(9)
    SEARCH_ADS_360_SYNC = ChangeClientTypeEnum.ChangeClientType.V(10)
    SEARCH_ADS_360_POST = ChangeClientTypeEnum.ChangeClientType.V(11)
    INTERNAL_TOOL = ChangeClientTypeEnum.ChangeClientType.V(12)
    OTHER = ChangeClientTypeEnum.ChangeClientType.V(13)
    def __init__(
        self,
    ) -> None: ...

global___ChangeClientTypeEnum = ChangeClientTypeEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v4.proto.resources.feed_mapping_pb2
import grpc

from .feed_mapping_service_pb2 import *

class FeedMappingServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetFeedMapping(
        self,
        request: global___GetFeedMappingRequest,
    ) -> google.ads.google_ads.v4.proto.resources.feed_mapping_pb2.FeedMapping: ...
    def MutateFeedMappings(
        self,
        request: global___MutateFeedMappingsRequest,
    ) -> global___MutateFeedMappingsResponse: ...

class FeedMappingServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetFeedMapping(
        self,
        request: global___GetFeedMappingRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v4.proto.resources.feed_mapping_pb2.FeedMapping: ...
    @abc.abstractmethod
    def MutateFeedMappings(
        self,
        request: global___MutateFeedMappingsRequest,
        context: grpc.ServicerContext,
    ) -> global___MutateFeedMappingsResponse: ...

def add_FeedMappingServiceServicer_to_server(
    servicer: FeedMappingServiceServicer, server: grpc.Server
) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v6.proto.common.criteria_pb2
import google.ads.google_ads.v6.proto.common.extensions_pb2
import google.ads.google_ads.v6.proto.enums.keyword_match_type_pb2
import google.ads.google_ads.v6.proto.enums.recommendation_type_pb2
import google.ads.google_ads.v6.proto.enums.target_cpa_opt_in_recommendation_goal_pb2
import google.ads.google_ads.v6.proto.resources.ad_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class Recommendation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class RecommendationImpact(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        BASE_METRICS_FIELD_NUMBER: builtins.int
        POTENTIAL_METRICS_FIELD_NUMBER: builtins.int
        @property
        def base_metrics(self) -> global___Recommendation.RecommendationMetrics: ...
        @property
        def potential_metrics(
            self,
        ) -> global___Recommendation.RecommendationMetrics: ...
        def __init__(
            self,
            *,
            base_metrics: typing.Optional[
                global___Recommendation.RecommendationMetrics
            ] = ...,
            potential_metrics: typing.Optional[
                global___Recommendation.RecommendationMetrics
            ] = ...,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing_extensions.Literal[
                "base_metrics",
                b"base_metrics",
                "potential_metrics",
                b"potential_metrics",
            ],
        ) -> builtins.bool: ...
        def ClearField(
            self,
            field_name: typing_extensions.Literal[
                "base_metrics",
                b"base_metrics",
                "potential_metrics",
                b"potential_metrics",
            ],
        ) -> None: ...
    class RecommendationMetrics(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        IMPRESSIONS_FIELD_NUMBER: builtins.int
        CLICKS_FIELD_NUMBER: builtins.int
        COST_MICROS_FIELD_NUMBER: builtins.int
        CONVERSIONS_FIELD_NUMBER: builtins.int
        VIDEO_VIEWS_FIELD_NUMBER: builtins.int
        impressions: builtins.float = ...
        clicks: builtins.float = ...
        cost_micros: builtins.int = ...
        conversions: builtins.float = ...
        video_views: builtins.float = ...
        def __init__(
            self,
            *,
            impressions: builtins.float = ...,
            clicks: builtins.float = ...,
            cost_micros: builtins.int = ...,
            conversions: builtins.float = ...,
            video_views: builtins.float = ...,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing_extensions.Literal[
                "_clicks",
                b"_clicks",
                "_conversions",
                b"_conversions",
                "_cost_micros",
                b"_cost_micros",
                "_impressions",
                b"_impressions",
                "_video_views",
                b"_video_views",
                "clicks",
                b"clicks",
                "conversions",
                b"conversions",
                "cost_micros",
                b"cost_micros",
                "impressions",
                b"impressions",
                "video_views",
                b"video_views",
            ],
        ) -> builtins.bool: ...
        def ClearField(
            self,
            field_name: typing_extensions.Literal[
                "_clicks",
                b"_clicks",
                "_conversions",
                b"_conversions",
                "_cost_micros",
                b"_cost_micros",
                "_impressions",
                b"_impressions",
                "_video_views",
                b"_video_views",
                "clicks",
                b"clicks",
                "conversions",
                b"conversions",
                "cost_micros",
                b"cost_micros",
                "impressions",
                b"impressions",
                "video_views",
                b"video_views",
            ],
        ) -> None: ...
        @typing.overload
        def WhichOneof(
            self, oneof_group: typing_extensions.Literal["_clicks", b"_clicks"]
        ) -> typing_extensions.Literal["clicks"]: ...
        @typing.overload
        def WhichOneof(
            self,
            oneof_group: typing_extensions.Literal["_conversions", b"_conversions"],
        ) -> typing_extensions.Literal["conversions"]: ...
        @typing.overload
        def WhichOneof(
            self,
            oneof_group: typing_extensions.Literal["_cost_micros", b"_cost_micros"],
        ) -> typing_extensions.Literal["cost_micros"]: ...
        @typing.overload
        def WhichOneof(
            self,
            oneof_group: typing_extensions.Literal["_impressions", b"_impressions"],
        ) -> typing_extensions.Literal["impressions"]: ...
        @typing.overload
        def WhichOneof(
            self,
            oneof_group: typing_extensions.Literal["_video_views", b"_video_views"],
        ) -> typing_extensions.Literal["video_views"]: ...
    class CampaignBudgetRecommendation(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        class CampaignBudgetRecommendationOption(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
            BUDGET_AMOUNT_MICROS_FIELD_NUMBER: builtins.int
            IMPACT_FIELD_NUMBER: builtins.int
            budget_amount_micros: builtins.int = ...
            @property
            def impact(self) -> global___Recommendation.RecommendationImpact: ...
            def __init__(
                self,
                *,
                budget_amount_micros: builtins.int = ...,
                impact: typing.Optional[
                    global___Recommendation.RecommendationImpact
                ] = ...,
            ) -> None: ...
            def HasField(
                self,
                field_name: typing_extensions.Literal[
                    "_budget_amount_micros",
                    b"_budget_amount_micros",
                    "budget_amount_micros",
                    b"budget_amount_micros",
                    "impact",
                    b"impact",
                ],
            ) -> builtins.bool: ...
            def ClearField(
                self,
                field_name: typing_extensions.Literal[
                    "_budget_amount_micros",
                    b"_budget_amount_micros",
                    "budget_amount_micros",
                    b"budget_amount_micros",
                    "impact",
                    b"impact",
                ],
            ) -> None: ...
            def WhichOneof(
                self,
                oneof_group: typing_extensions.Literal[
                    "_budget_amount_micros", b"_budget_amount_micros"
                ],
            ) -> typing_extensions.Literal["budget_amount_micros"]: ...
        CURRENT_BUDGET_AMOUNT_MICROS_FIELD_NUMBER: builtins.int
        RECOMMENDED_BUDGET_AMOUNT_MICROS_FIELD_NUMBER: builtins.int
        BUDGET_OPTIONS_FIELD_NUMBER: builtins.int
        current_budget_amount_micros: builtins.int = ...
        recommended_budget_amount_micros: builtins.int = ...
        @property
        def budget_options(
            self,
        ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
            global___Recommendation.CampaignBudgetRecommendation.CampaignBudgetRecommendationOption
        ]: ...
        def __init__(
            self,
            *,
            current_budget_amount_micros: builtins.int = ...,
            recommended_budget_amount_micros: builtins.int = ...,
            budget_options: typing.Optional[
                typing.Iterable[
                    global___Recommendation.CampaignBudgetRecommendation.CampaignBudgetRecommendationOption
                ]
            ] = ...,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing_extensions.Literal[
                "_current_budget_amount_micros",
                b"_current_budget_amount_micros",
                "_recommended_budget_amount_micros",
                b"_recommended_budget_amount_micros",
                "current_budget_amount_micros",
                b"current_budget_amount_micros",
                "recommended_budget_amount_micros",
                b"recommended_budget_amount_micros",
            ],
        ) -> builtins.bool: ...
        def ClearField(
            self,
            field_name: typing_extensions.Literal[
                "_current_budget_amount_micros",
                b"_current_budget_amount_micros",
                "_recommended_budget_amount_micros",
                b"_recommended_budget_amount_micros",
                "budget_options",
                b"budget_options",
                "current_budget_amount_micros",
                b"current_budget_amount_micros",
                "recommended_budget_amount_micros",
                b"recommended_budget_amount_micros",
            ],
        ) -> None: ...
        @typing.overload
        def WhichOneof(
            self,
            oneof_group: typing_extensions.Literal[
                "_current_budget_amount_micros", b"_current_budget_amount_micros"
            ],
        ) -> typing_extensions.Literal["current_budget_amount_micros"]: ...
        @typing.overload
        def WhichOneof(
            self,
            oneof_group: typing_extensions.Literal[
                "_recommended_budget_amount_micros",
                b"_recommended_budget_amount_micros",
            ],
        ) -> typing_extensions.Literal["recommended_budget_amount_micros"]: ...
    class KeywordRecommendation(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        KEYWORD_FIELD_NUMBER: builtins.int
        RECOMMENDED_CPC_BID_MICROS_FIELD_NUMBER: builtins.int
        recommended_cpc_bid_micros: builtins.int = ...
        @property
        def keyword(
            self,
        ) -> google.ads.google_ads.v6.proto.common.criteria_pb2.KeywordInfo: ...
        def __init__(
            self,
            *,
            keyword: typing.Optional[
                google.ads.google_ads.v6.proto.common.criteria_pb2.KeywordInfo
            ] = ...,
            recommended_cpc_bid_micros: builtins.int = ...,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing_extensions.Literal[
                "_recommended_cpc_bid_micros",
                b"_recommended_cpc_bid_micros",
                "keyword",
                b"keyword",
                "recommended_cpc_bid_micros",
                b"recommended_cpc_bid_micros",
            ],
        ) -> builtins.bool: ...
        def ClearField(
            self,
            field_name: typing_extensions.Literal[
                "_recommended_cpc_bid_micros",
                b"_recommended_cpc_bid_micros",
                "keyword",
                b"keyword",
                "recommended_cpc_bid_micros",
                b"recommended_cpc_bid_micros",
            ],
        ) -> None: ...
        def WhichOneof(
            self,
            oneof_group: typing_extensions.Literal[
                "_recommended_cpc_bid_micros", b"_recommended_cpc_bid_micros"
            ],
        ) -> typing_extensions.Literal["recommended_cpc_bid_micros"]: ...
    class TextAdRecommendation(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        AD_FIELD_NUMBER: builtins.int
        CREATION_DATE_FIELD_NUMBER: builtins.int
        AUTO_APPLY_DATE_FIELD_NUMBER: builtins.int
        creation_date: typing.Text = ...
        auto_apply_date: typing.Text = ...
        @property
        def ad(self) -> google.ads.google_ads.v6.proto.resources.ad_pb2.Ad: ...
        def __init__(
            self,
            *,
            ad: typing.Optional[
                google.ads.google_ads.v6.proto.resources.ad_pb2.Ad
            ] = ...,
            creation_date: typing.Text = ...,
            auto_apply_date: typing.Text = ...,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing_extensions.Literal[
                "_auto_apply_date",
                b"_auto_apply_date",
                "_creation_date",
                b"_creation_date",
                "ad",
                b"ad",
                "auto_apply_date",
                b"auto_apply_date",
                "creation_date",
                b"creation_date",
            ],
        ) -> builtins.bool: ...
        def ClearField(
            self,
            field_name: typing_extensions.Literal[
                "_auto_apply_date",
                b"_auto_apply_date",
                "_creation_date",
                b"_creation_date",
                "ad",
                b"ad",
                "auto_apply_date",
                b"auto_apply_date",
                "creation_date",
                b"creation_date",
            ],
        ) -> None: ...
        @typing.overload
        def WhichOneof(
            self,
            oneof_group: typing_extensions.Literal[
                "_auto_apply_date", b"_auto_apply_date"
            ],
        ) -> typing_extensions.Literal["auto_apply_date"]: ...
        @typing.overload
        def WhichOneof(
            self,
            oneof_group: typing_extensions.Literal["_creation_date", b"_creation_date"],
        ) -> typing_extensions.Literal["creation_date"]: ...
    class ResponsiveSearchAdRecommendation(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        AD_FIELD_NUMBER: builtins.int
        @property
        def ad(self) -> google.ads.google_ads.v6.proto.resources.ad_pb2.Ad: ...
        def __init__(
            self,
            *,
            ad: typing.Optional[
                google.ads.google_ads.v6.proto.resources.ad_pb2.Ad
            ] = ...,
        ) -> None: ...
        def HasField(
            self, field_name: typing_extensions.Literal["ad", b"ad"]
        ) -> builtins.bool: ...
        def ClearField(
            self, field_name: typing_extensions.Literal["ad", b"ad"]
        ) -> None: ...
    class TargetCpaOptInRecommendation(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        class TargetCpaOptInRecommendationOption(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
            GOAL_FIELD_NUMBER: builtins.int
            TARGET_CPA_MICROS_FIELD_NUMBER: builtins.int
            REQUIRED_CAMPAIGN_BUDGET_AMOUNT_MICROS_FIELD_NUMBER: builtins.int
            IMPACT_FIELD_NUMBER: builtins.int
            goal: google.ads.google_ads.v6.proto.enums.target_cpa_opt_in_recommendation_goal_pb2.TargetCpaOptInRecommendationGoalEnum.TargetCpaOptInRecommendationGoal.V = (
                ...
            )
            target_cpa_micros: builtins.int = ...
            required_campaign_budget_amount_micros: builtins.int = ...
            @property
            def impact(self) -> global___Recommendation.RecommendationImpact: ...
            def __init__(
                self,
                *,
                goal: google.ads.google_ads.v6.proto.enums.target_cpa_opt_in_recommendation_goal_pb2.TargetCpaOptInRecommendationGoalEnum.TargetCpaOptInRecommendationGoal.V = ...,
                target_cpa_micros: builtins.int = ...,
                required_campaign_budget_amount_micros: builtins.int = ...,
                impact: typing.Optional[
                    global___Recommendation.RecommendationImpact
                ] = ...,
            ) -> None: ...
            def HasField(
                self,
                field_name: typing_extensions.Literal[
                    "_required_campaign_budget_amount_micros",
                    b"_required_campaign_budget_amount_micros",
                    "_target_cpa_micros",
                    b"_target_cpa_micros",
                    "impact",
                    b"impact",
                    "required_campaign_budget_amount_micros",
                    b"required_campaign_budget_amount_micros",
                    "target_cpa_micros",
                    b"target_cpa_micros",
                ],
            ) -> builtins.bool: ...
            def ClearField(
                self,
                field_name: typing_extensions.Literal[
                    "_required_campaign_budget_amount_micros",
                    b"_required_campaign_budget_amount_micros",
                    "_target_cpa_micros",
                    b"_target_cpa_micros",
                    "goal",
                    b"goal",
                    "impact",
                    b"impact",
                    "required_campaign_budget_amount_micros",
                    b"required_campaign_budget_amount_micros",
                    "target_cpa_micros",
                    b"target_cpa_micros",
                ],
            ) -> None: ...
            @typing.overload
            def WhichOneof(
                self,
                oneof_group: typing_extensions.Literal[
                    "_required_campaign_budget_amount_micros",
                    b"_required_campaign_budget_amount_micros",
                ],
            ) -> typing_extensions.Literal[
                "required_campaign_budget_amount_micros"
            ]: ...
            @typing.overload
            def WhichOneof(
                self,
                oneof_group: typing_extensions.Literal[
                    "_target_cpa_micros", b"_target_cpa_micros"
                ],
            ) -> typing_extensions.Literal["target_cpa_micros"]: ...
        OPTIONS_FIELD_NUMBER: builtins.int
        RECOMMENDED_TARGET_CPA_MICROS_FIELD_NUMBER: builtins.int
        recommended_target_cpa_micros: builtins.int = ...
        @property
        def options(
            self,
        ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
            global___Recommendation.TargetCpaOptInRecommendation.TargetCpaOptInRecommendationOption
        ]: ...
        def __init__(
            self,
            *,
            options: typing.Optional[
                typing.Iterable[
                    global___Recommendation.TargetCpaOptInRecommendation.TargetCpaOptInRecommendationOption
                ]
            ] = ...,
            recommended_target_cpa_micros: builtins.int = ...,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing_extensions.Literal[
                "_recommended_target_cpa_micros",
                b"_recommended_target_cpa_micros",
                "recommended_target_cpa_micros",
                b"recommended_target_cpa_micros",
            ],
        ) -> builtins.bool: ...
        def ClearField(
            self,
            field_name: typing_extensions.Literal[
                "_recommended_target_cpa_micros",
                b"_recommended_target_cpa_micros",
                "options",
                b"options",
                "recommended_target_cpa_micros",
                b"recommended_target_cpa_micros",
            ],
        ) -> None: ...
        def WhichOneof(
            self,
            oneof_group: typing_extensions.Literal[
                "_recommended_target_cpa_micros", b"_recommended_target_cpa_micros"
            ],
        ) -> typing_extensions.Literal["recommended_target_cpa_micros"]: ...
    class MaximizeConversionsOptInRecommendation(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        RECOMMENDED_BUDGET_AMOUNT_MICROS_FIELD_NUMBER: builtins.int
        recommended_budget_amount_micros: builtins.int = ...
        def __init__(
            self,
            *,
            recommended_budget_amount_micros: builtins.int = ...,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing_extensions.Literal[
                "_recommended_budget_amount_micros",
                b"_recommended_budget_amount_micros",
                "recommended_budget_amount_micros",
                b"recommended_budget_amount_micros",
            ],
        ) -> builtins.bool: ...
        def ClearField(
            self,
            field_name: typing_extensions.Literal[
                "_recommended_budget_amount_micros",
                b"_recommended_budget_amount_micros",
                "recommended_budget_amount_micros",
                b"recommended_budget_amount_micros",
            ],
        ) -> None: ...
        def WhichOneof(
            self,
            oneof_group: typing_extensions.Literal[
                "_recommended_budget_amount_micros",
                b"_recommended_budget_amount_micros",
            ],
        ) -> typing_extensions.Literal["recommended_budget_amount_micros"]: ...
    class CalloutExtensionRecommendation(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        RECOMMENDED_EXTENSIONS_FIELD_NUMBER: builtins.int
        @property
        def recommended_extensions(
            self,
        ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
            google.ads.google_ads.v6.proto.common.extensions_pb2.CalloutFeedItem
        ]: ...
        def __init__(
            self,
            *,
            recommended_extensions: typing.Optional[
                typing.Iterable[
                    google.ads.google_ads.v6.proto.common.extensions_pb2.CalloutFeedItem
                ]
            ] = ...,
        ) -> None: ...
        def ClearField(
            self,
            field_name: typing_extensions.Literal[
                "recommended_extensions", b"recommended_extensions"
            ],
        ) -> None: ...
    class EnhancedCpcOptInRecommendation(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        def __init__(
            self,
        ) -> None: ...
    class SearchPartnersOptInRecommendation(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        def __init__(
            self,
        ) -> None: ...
    class MaximizeClicksOptInRecommendation(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        RECOMMENDED_BUDGET_AMOUNT_MICROS_FIELD_NUMBER: builtins.int
        recommended_budget_amount_micros: builtins.int = ...
        def __init__(
            self,
            *,
            recommended_budget_amount_micros: builtins.int = ...,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing_extensions.Literal[
                "_recommended_budget_amount_micros",
                b"_recommended_budget_amount_micros",
                "recommended_budget_amount_micros",
                b"recommended_budget_amount_micros",
            ],
        ) -> builtins.bool: ...
        def ClearField(
            self,
            field_name: typing_extensions.Literal[
                "_recommended_budget_amount_micros",
                b"_recommended_budget_amount_micros",
                "recommended_budget_amount_micros",
                b"recommended_budget_amount_micros",
            ],
        ) -> None: ...
        def WhichOneof(
            self,
            oneof_group: typing_extensions.Literal[
                "_recommended_budget_amount_micros",
                b"_recommended_budget_amount_micros",
            ],
        ) -> typing_extensions.Literal["recommended_budget_amount_micros"]: ...
    class MoveUnusedBudgetRecommendation(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        EXCESS_CAMPAIGN_BUDGET_FIELD_NUMBER: builtins.int
        BUDGET_RECOMMENDATION_FIELD_NUMBER: builtins.int
        excess_campaign_budget: typing.Text = ...
        @property
        def budget_recommendation(
            self,
        ) -> global___Recommendation.CampaignBudgetRecommendation: ...
        def __init__(
            self,
            *,
            excess_campaign_budget: typing.Text = ...,
            budget_recommendation: typing.Optional[
                global___Recommendation.CampaignBudgetRecommendation
            ] = ...,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing_extensions.Literal[
                "_excess_campaign_budget",
                b"_excess_campaign_budget",
                "budget_recommendation",
                b"budget_recommendation",
                "excess_campaign_budget",
                b"excess_campaign_budget",
            ],
        ) -> builtins.bool: ...
        def ClearField(
            self,
            field_name: typing_extensions.Literal[
                "_excess_campaign_budget",
                b"_excess_campaign_budget",
                "budget_recommendation",
                b"budget_recommendation",
                "excess_campaign_budget",
                b"excess_campaign_budget",
            ],
        ) -> None: ...
        def WhichOneof(
            self,
            oneof_group: typing_extensions.Literal[
                "_excess_campaign_budget", b"_excess_campaign_budget"
            ],
        ) -> typing_extensions.Literal["excess_campaign_budget"]: ...
    class OptimizeAdRotationRecommendation(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        def __init__(
            self,
        ) -> None: ...
    class SitelinkExtensionRecommendation(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        RECOMMENDED_EXTENSIONS_FIELD_NUMBER: builtins.int
        @property
        def recommended_extensions(
            self,
        ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
            google.ads.google_ads.v6.proto.common.extensions_pb2.SitelinkFeedItem
        ]: ...
        def __init__(
            self,
            *,
            recommended_extensions: typing.Optional[
                typing.Iterable[
                    google.ads.google_ads.v6.proto.common.extensions_pb2.SitelinkFeedItem
                ]
            ] = ...,
        ) -> None: ...
        def ClearField(
            self,
            field_name: typing_extensions.Literal[
                "recommended_extensions", b"recommended_extensions"
            ],
        ) -> None: ...
    class KeywordMatchTypeRecommendation(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        KEYWORD_FIELD_NUMBER: builtins.int
        RECOMMENDED_MATCH_TYPE_FIELD_NUMBER: builtins.int
        recommended_match_type: google.ads.google_ads.v6.proto.enums.keyword_match_type_pb2.KeywordMatchTypeEnum.KeywordMatchType.V = (
            ...
        )
        @property
        def keyword(
            self,
        ) -> google.ads.google_ads.v6.proto.common.criteria_pb2.KeywordInfo: ...
        def __init__(
            self,
            *,
            keyword: typing.Optional[
                google.ads.google_ads.v6.proto.common.criteria_pb2.KeywordInfo
            ] = ...,
            recommended_match_type: google.ads.google_ads.v6.proto.enums.keyword_match_type_pb2.KeywordMatchTypeEnum.KeywordMatchType.V = ...,
        ) -> None: ...
        def HasField(
            self, field_name: typing_extensions.Literal["keyword", b"keyword"]
        ) -> builtins.bool: ...
        def ClearField(
            self,
            field_name: typing_extensions.Literal[
                "keyword",
                b"keyword",
                "recommended_match_type",
                b"recommended_match_type",
            ],
        ) -> None: ...
    class CallExtensionRecommendation(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        RECOMMENDED_EXTENSIONS_FIELD_NUMBER: builtins.int
        @property
        def recommended_extensions(
            self,
        ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
            google.ads.google_ads.v6.proto.common.extensions_pb2.CallFeedItem
        ]: ...
        def __init__(
            self,
            *,
            recommended_extensions: typing.Optional[
                typing.Iterable[
                    google.ads.google_ads.v6.proto.common.extensions_pb2.CallFeedItem
                ]
            ] = ...,
        ) -> None: ...
        def ClearField(
            self,
            field_name: typing_extensions.Literal[
                "recommended_extensions", b"recommended_extensions"
            ],
        ) -> None: ...
    class TargetRoasOptInRecommendation(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        RECOMMENDED_TARGET_ROAS_FIELD_NUMBER: builtins.int
        REQUIRED_CAMPAIGN_BUDGET_AMOUNT_MICROS_FIELD_NUMBER: builtins.int
        recommended_target_roas: builtins.float = ...
        required_campaign_budget_amount_micros: builtins.int = ...
        def __init__(
            self,
            *,
            recommended_target_roas: builtins.float = ...,
            required_campaign_budget_amount_micros: builtins.int = ...,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing_extensions.Literal[
                "_recommended_target_roas",
                b"_recommended_target_roas",
                "_required_campaign_budget_amount_micros",
                b"_required_campaign_budget_amount_micros",
                "recommended_target_roas",
                b"recommended_target_roas",
                "required_campaign_budget_amount_micros",
                b"required_campaign_budget_amount_micros",
            ],
        ) -> builtins.bool: ...
        def ClearField(
            self,
            field_name: typing_extensions.Literal[
                "_recommended_target_roas",
                b"_recommended_target_roas",
                "_required_campaign_budget_amount_micros",
                b"_required_campaign_budget_amount_micros",
                "recommended_target_roas",
                b"recommended_target_roas",
                "required_campaign_budget_amount_micros",
                b"required_campaign_budget_amount_micros",
            ],
        ) -> None: ...
        @typing.overload
        def WhichOneof(
            self,
            oneof_group: typing_extensions.Literal[
                "_recommended_target_roas", b"_recommended_target_roas"
            ],
        ) -> typing_extensions.Literal["recommended_target_roas"]: ...
        @typing.overload
        def WhichOneof(
            self,
            oneof_group: typing_extensions.Literal[
                "_required_campaign_budget_amount_micros",
                b"_required_campaign_budget_amount_micros",
            ],
        ) -> typing_extensions.Literal["required_campaign_budget_amount_micros"]: ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    IMPACT_FIELD_NUMBER: builtins.int
    CAMPAIGN_BUDGET_FIELD_NUMBER: builtins.int
    CAMPAIGN_FIELD_NUMBER: builtins.int
    AD_GROUP_FIELD_NUMBER: builtins.int
    DISMISSED_FIELD_NUMBER: builtins.int
    CAMPAIGN_BUDGET_RECOMMENDATION_FIELD_NUMBER: builtins.int
    FORECASTING_CAMPAIGN_BUDGET_RECOMMENDATION_FIELD_NUMBER: builtins.int
    KEYWORD_RECOMMENDATION_FIELD_NUMBER: builtins.int
    TEXT_AD_RECOMMENDATION_FIELD_NUMBER: builtins.int
    TARGET_CPA_OPT_IN_RECOMMENDATION_FIELD_NUMBER: builtins.int
    MAXIMIZE_CONVERSIONS_OPT_IN_RECOMMENDATION_FIELD_NUMBER: builtins.int
    ENHANCED_CPC_OPT_IN_RECOMMENDATION_FIELD_NUMBER: builtins.int
    SEARCH_PARTNERS_OPT_IN_RECOMMENDATION_FIELD_NUMBER: builtins.int
    MAXIMIZE_CLICKS_OPT_IN_RECOMMENDATION_FIELD_NUMBER: builtins.int
    OPTIMIZE_AD_ROTATION_RECOMMENDATION_FIELD_NUMBER: builtins.int
    CALLOUT_EXTENSION_RECOMMENDATION_FIELD_NUMBER: builtins.int
    SITELINK_EXTENSION_RECOMMENDATION_FIELD_NUMBER: builtins.int
    CALL_EXTENSION_RECOMMENDATION_FIELD_NUMBER: builtins.int
    KEYWORD_MATCH_TYPE_RECOMMENDATION_FIELD_NUMBER: builtins.int
    MOVE_UNUSED_BUDGET_RECOMMENDATION_FIELD_NUMBER: builtins.int
    TARGET_ROAS_OPT_IN_RECOMMENDATION_FIELD_NUMBER: builtins.int
    RESPONSIVE_SEARCH_AD_RECOMMENDATION_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    type: google.ads.google_ads.v6.proto.enums.recommendation_type_pb2.RecommendationTypeEnum.RecommendationType.V = (
        ...
    )
    campaign_budget: typing.Text = ...
    campaign: typing.Text = ...
    ad_group: typing.Text = ...
    dismissed: builtins.bool = ...
    @property
    def impact(self) -> global___Recommendation.RecommendationImpact: ...
    @property
    def campaign_budget_recommendation(
        self,
    ) -> global___Recommendation.CampaignBudgetRecommendation: ...
    @property
    def forecasting_campaign_budget_recommendation(
        self,
    ) -> global___Recommendation.CampaignBudgetRecommendation: ...
    @property
    def keyword_recommendation(
        self,
    ) -> global___Recommendation.KeywordRecommendation: ...
    @property
    def text_ad_recommendation(
        self,
    ) -> global___Recommendation.TextAdRecommendation: ...
    @property
    def target_cpa_opt_in_recommendation(
        self,
    ) -> global___Recommendation.TargetCpaOptInRecommendation: ...
    @property
    def maximize_conversions_opt_in_recommendation(
        self,
    ) -> global___Recommendation.MaximizeConversionsOptInRecommendation: ...
    @property
    def enhanced_cpc_opt_in_recommendation(
        self,
    ) -> global___Recommendation.EnhancedCpcOptInRecommendation: ...
    @property
    def search_partners_opt_in_recommendation(
        self,
    ) -> global___Recommendation.SearchPartnersOptInRecommendation: ...
    @property
    def maximize_clicks_opt_in_recommendation(
        self,
    ) -> global___Recommendation.MaximizeClicksOptInRecommendation: ...
    @property
    def optimize_ad_rotation_recommendation(
        self,
    ) -> global___Recommendation.OptimizeAdRotationRecommendation: ...
    @property
    def callout_extension_recommendation(
        self,
    ) -> global___Recommendation.CalloutExtensionRecommendation: ...
    @property
    def sitelink_extension_recommendation(
        self,
    ) -> global___Recommendation.SitelinkExtensionRecommendation: ...
    @property
    def call_extension_recommendation(
        self,
    ) -> global___Recommendation.CallExtensionRecommendation: ...
    @property
    def keyword_match_type_recommendation(
        self,
    ) -> global___Recommendation.KeywordMatchTypeRecommendation: ...
    @property
    def move_unused_budget_recommendation(
        self,
    ) -> global___Recommendation.MoveUnusedBudgetRecommendation: ...
    @property
    def target_roas_opt_in_recommendation(
        self,
    ) -> global___Recommendation.TargetRoasOptInRecommendation: ...
    @property
    def responsive_search_ad_recommendation(
        self,
    ) -> global___Recommendation.ResponsiveSearchAdRecommendation: ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        type: google.ads.google_ads.v6.proto.enums.recommendation_type_pb2.RecommendationTypeEnum.RecommendationType.V = ...,
        impact: typing.Optional[global___Recommendation.RecommendationImpact] = ...,
        campaign_budget: typing.Text = ...,
        campaign: typing.Text = ...,
        ad_group: typing.Text = ...,
        dismissed: builtins.bool = ...,
        campaign_budget_recommendation: typing.Optional[
            global___Recommendation.CampaignBudgetRecommendation
        ] = ...,
        forecasting_campaign_budget_recommendation: typing.Optional[
            global___Recommendation.CampaignBudgetRecommendation
        ] = ...,
        keyword_recommendation: typing.Optional[
            global___Recommendation.KeywordRecommendation
        ] = ...,
        text_ad_recommendation: typing.Optional[
            global___Recommendation.TextAdRecommendation
        ] = ...,
        target_cpa_opt_in_recommendation: typing.Optional[
            global___Recommendation.TargetCpaOptInRecommendation
        ] = ...,
        maximize_conversions_opt_in_recommendation: typing.Optional[
            global___Recommendation.MaximizeConversionsOptInRecommendation
        ] = ...,
        enhanced_cpc_opt_in_recommendation: typing.Optional[
            global___Recommendation.EnhancedCpcOptInRecommendation
        ] = ...,
        search_partners_opt_in_recommendation: typing.Optional[
            global___Recommendation.SearchPartnersOptInRecommendation
        ] = ...,
        maximize_clicks_opt_in_recommendation: typing.Optional[
            global___Recommendation.MaximizeClicksOptInRecommendation
        ] = ...,
        optimize_ad_rotation_recommendation: typing.Optional[
            global___Recommendation.OptimizeAdRotationRecommendation
        ] = ...,
        callout_extension_recommendation: typing.Optional[
            global___Recommendation.CalloutExtensionRecommendation
        ] = ...,
        sitelink_extension_recommendation: typing.Optional[
            global___Recommendation.SitelinkExtensionRecommendation
        ] = ...,
        call_extension_recommendation: typing.Optional[
            global___Recommendation.CallExtensionRecommendation
        ] = ...,
        keyword_match_type_recommendation: typing.Optional[
            global___Recommendation.KeywordMatchTypeRecommendation
        ] = ...,
        move_unused_budget_recommendation: typing.Optional[
            global___Recommendation.MoveUnusedBudgetRecommendation
        ] = ...,
        target_roas_opt_in_recommendation: typing.Optional[
            global___Recommendation.TargetRoasOptInRecommendation
        ] = ...,
        responsive_search_ad_recommendation: typing.Optional[
            global___Recommendation.ResponsiveSearchAdRecommendation
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_ad_group",
            b"_ad_group",
            "_campaign",
            b"_campaign",
            "_campaign_budget",
            b"_campaign_budget",
            "_dismissed",
            b"_dismissed",
            "ad_group",
            b"ad_group",
            "call_extension_recommendation",
            b"call_extension_recommendation",
            "callout_extension_recommendation",
            b"callout_extension_recommendation",
            "campaign",
            b"campaign",
            "campaign_budget",
            b"campaign_budget",
            "campaign_budget_recommendation",
            b"campaign_budget_recommendation",
            "dismissed",
            b"dismissed",
            "enhanced_cpc_opt_in_recommendation",
            b"enhanced_cpc_opt_in_recommendation",
            "forecasting_campaign_budget_recommendation",
            b"forecasting_campaign_budget_recommendation",
            "impact",
            b"impact",
            "keyword_match_type_recommendation",
            b"keyword_match_type_recommendation",
            "keyword_recommendation",
            b"keyword_recommendation",
            "maximize_clicks_opt_in_recommendation",
            b"maximize_clicks_opt_in_recommendation",
            "maximize_conversions_opt_in_recommendation",
            b"maximize_conversions_opt_in_recommendation",
            "move_unused_budget_recommendation",
            b"move_unused_budget_recommendation",
            "optimize_ad_rotation_recommendation",
            b"optimize_ad_rotation_recommendation",
            "recommendation",
            b"recommendation",
            "responsive_search_ad_recommendation",
            b"responsive_search_ad_recommendation",
            "search_partners_opt_in_recommendation",
            b"search_partners_opt_in_recommendation",
            "sitelink_extension_recommendation",
            b"sitelink_extension_recommendation",
            "target_cpa_opt_in_recommendation",
            b"target_cpa_opt_in_recommendation",
            "target_roas_opt_in_recommendation",
            b"target_roas_opt_in_recommendation",
            "text_ad_recommendation",
            b"text_ad_recommendation",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_ad_group",
            b"_ad_group",
            "_campaign",
            b"_campaign",
            "_campaign_budget",
            b"_campaign_budget",
            "_dismissed",
            b"_dismissed",
            "ad_group",
            b"ad_group",
            "call_extension_recommendation",
            b"call_extension_recommendation",
            "callout_extension_recommendation",
            b"callout_extension_recommendation",
            "campaign",
            b"campaign",
            "campaign_budget",
            b"campaign_budget",
            "campaign_budget_recommendation",
            b"campaign_budget_recommendation",
            "dismissed",
            b"dismissed",
            "enhanced_cpc_opt_in_recommendation",
            b"enhanced_cpc_opt_in_recommendation",
            "forecasting_campaign_budget_recommendation",
            b"forecasting_campaign_budget_recommendation",
            "impact",
            b"impact",
            "keyword_match_type_recommendation",
            b"keyword_match_type_recommendation",
            "keyword_recommendation",
            b"keyword_recommendation",
            "maximize_clicks_opt_in_recommendation",
            b"maximize_clicks_opt_in_recommendation",
            "maximize_conversions_opt_in_recommendation",
            b"maximize_conversions_opt_in_recommendation",
            "move_unused_budget_recommendation",
            b"move_unused_budget_recommendation",
            "optimize_ad_rotation_recommendation",
            b"optimize_ad_rotation_recommendation",
            "recommendation",
            b"recommendation",
            "resource_name",
            b"resource_name",
            "responsive_search_ad_recommendation",
            b"responsive_search_ad_recommendation",
            "search_partners_opt_in_recommendation",
            b"search_partners_opt_in_recommendation",
            "sitelink_extension_recommendation",
            b"sitelink_extension_recommendation",
            "target_cpa_opt_in_recommendation",
            b"target_cpa_opt_in_recommendation",
            "target_roas_opt_in_recommendation",
            b"target_roas_opt_in_recommendation",
            "text_ad_recommendation",
            b"text_ad_recommendation",
            "type",
            b"type",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_ad_group", b"_ad_group"]
    ) -> typing_extensions.Literal["ad_group"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_campaign", b"_campaign"]
    ) -> typing_extensions.Literal["campaign"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_campaign_budget", b"_campaign_budget"],
    ) -> typing_extensions.Literal["campaign_budget"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_dismissed", b"_dismissed"]
    ) -> typing_extensions.Literal["dismissed"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["recommendation", b"recommendation"],
    ) -> typing_extensions.Literal[
        "campaign_budget_recommendation",
        "forecasting_campaign_budget_recommendation",
        "keyword_recommendation",
        "text_ad_recommendation",
        "target_cpa_opt_in_recommendation",
        "maximize_conversions_opt_in_recommendation",
        "enhanced_cpc_opt_in_recommendation",
        "search_partners_opt_in_recommendation",
        "maximize_clicks_opt_in_recommendation",
        "optimize_ad_rotation_recommendation",
        "callout_extension_recommendation",
        "sitelink_extension_recommendation",
        "call_extension_recommendation",
        "keyword_match_type_recommendation",
        "move_unused_budget_recommendation",
        "target_roas_opt_in_recommendation",
        "responsive_search_ad_recommendation",
    ]: ...

global___Recommendation = Recommendation



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v6.proto.resources.geo_target_constant_pb2
import grpc

from .geo_target_constant_service_pb2 import *

class GeoTargetConstantServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetGeoTargetConstant(
        self,
        request: global___GetGeoTargetConstantRequest,
    ) -> google.ads.google_ads.v6.proto.resources.geo_target_constant_pb2.GeoTargetConstant: ...
    def SuggestGeoTargetConstants(
        self,
        request: global___SuggestGeoTargetConstantsRequest,
    ) -> global___SuggestGeoTargetConstantsResponse: ...

class GeoTargetConstantServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetGeoTargetConstant(
        self,
        request: global___GetGeoTargetConstantRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v6.proto.resources.geo_target_constant_pb2.GeoTargetConstant: ...
    @abc.abstractmethod
    def SuggestGeoTargetConstants(
        self,
        request: global___SuggestGeoTargetConstantsRequest,
        context: grpc.ServicerContext,
    ) -> global___SuggestGeoTargetConstantsResponse: ...

def add_GeoTargetConstantServiceServicer_to_server(
    servicer: GeoTargetConstantServiceServicer, server: grpc.Server
) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class UserListTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _UserListType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[UserListType.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = UserListTypeEnum.UserListType.V(0)
        UNKNOWN = UserListTypeEnum.UserListType.V(1)
        REMARKETING = UserListTypeEnum.UserListType.V(2)
        LOGICAL = UserListTypeEnum.UserListType.V(3)
        EXTERNAL_REMARKETING = UserListTypeEnum.UserListType.V(4)
        RULE_BASED = UserListTypeEnum.UserListType.V(5)
        SIMILAR = UserListTypeEnum.UserListType.V(6)
        CRM_BASED = UserListTypeEnum.UserListType.V(7)
    class UserListType(metaclass=_UserListType):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = UserListTypeEnum.UserListType.V(0)
    UNKNOWN = UserListTypeEnum.UserListType.V(1)
    REMARKETING = UserListTypeEnum.UserListType.V(2)
    LOGICAL = UserListTypeEnum.UserListType.V(3)
    EXTERNAL_REMARKETING = UserListTypeEnum.UserListType.V(4)
    RULE_BASED = UserListTypeEnum.UserListType.V(5)
    SIMILAR = UserListTypeEnum.UserListType.V(6)
    CRM_BASED = UserListTypeEnum.UserListType.V(7)
    def __init__(
        self,
    ) -> None: ...

global___UserListTypeEnum = UserListTypeEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v4.proto.resources.customer_extension_setting_pb2
import grpc

from .customer_extension_setting_service_pb2 import *

class CustomerExtensionSettingServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetCustomerExtensionSetting(
        self,
        request: global___GetCustomerExtensionSettingRequest,
    ) -> google.ads.google_ads.v4.proto.resources.customer_extension_setting_pb2.CustomerExtensionSetting: ...
    def MutateCustomerExtensionSettings(
        self,
        request: global___MutateCustomerExtensionSettingsRequest,
    ) -> global___MutateCustomerExtensionSettingsResponse: ...

class CustomerExtensionSettingServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetCustomerExtensionSetting(
        self,
        request: global___GetCustomerExtensionSettingRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v4.proto.resources.customer_extension_setting_pb2.CustomerExtensionSetting: ...
    @abc.abstractmethod
    def MutateCustomerExtensionSettings(
        self,
        request: global___MutateCustomerExtensionSettingsRequest,
        context: grpc.ServicerContext,
    ) -> global___MutateCustomerExtensionSettingsResponse: ...

def add_CustomerExtensionSettingServiceServicer_to_server(
    servicer: CustomerExtensionSettingServiceServicer, server: grpc.Server
) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class ReachPlanAgeRangeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _ReachPlanAgeRange(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            ReachPlanAgeRange.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(0)
        UNKNOWN = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(1)
        AGE_RANGE_18_24 = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(503001)
        AGE_RANGE_18_34 = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(2)
        AGE_RANGE_18_44 = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(3)
        AGE_RANGE_18_49 = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(4)
        AGE_RANGE_18_54 = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(5)
        AGE_RANGE_18_64 = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(6)
        AGE_RANGE_18_65_UP = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(7)
        AGE_RANGE_21_34 = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(8)
        AGE_RANGE_25_34 = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(503002)
        AGE_RANGE_25_44 = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(9)
        AGE_RANGE_25_49 = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(10)
        AGE_RANGE_25_54 = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(11)
        AGE_RANGE_25_64 = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(12)
        AGE_RANGE_25_65_UP = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(13)
        AGE_RANGE_35_44 = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(503003)
        AGE_RANGE_35_49 = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(14)
        AGE_RANGE_35_54 = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(15)
        AGE_RANGE_35_64 = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(16)
        AGE_RANGE_35_65_UP = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(17)
        AGE_RANGE_45_54 = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(503004)
        AGE_RANGE_45_64 = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(18)
        AGE_RANGE_45_65_UP = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(19)
        AGE_RANGE_50_65_UP = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(20)
        AGE_RANGE_55_64 = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(503005)
        AGE_RANGE_55_65_UP = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(21)
        AGE_RANGE_65_UP = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(503006)
    class ReachPlanAgeRange(metaclass=_ReachPlanAgeRange):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(0)
    UNKNOWN = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(1)
    AGE_RANGE_18_24 = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(503001)
    AGE_RANGE_18_34 = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(2)
    AGE_RANGE_18_44 = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(3)
    AGE_RANGE_18_49 = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(4)
    AGE_RANGE_18_54 = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(5)
    AGE_RANGE_18_64 = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(6)
    AGE_RANGE_18_65_UP = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(7)
    AGE_RANGE_21_34 = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(8)
    AGE_RANGE_25_34 = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(503002)
    AGE_RANGE_25_44 = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(9)
    AGE_RANGE_25_49 = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(10)
    AGE_RANGE_25_54 = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(11)
    AGE_RANGE_25_64 = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(12)
    AGE_RANGE_25_65_UP = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(13)
    AGE_RANGE_35_44 = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(503003)
    AGE_RANGE_35_49 = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(14)
    AGE_RANGE_35_54 = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(15)
    AGE_RANGE_35_64 = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(16)
    AGE_RANGE_35_65_UP = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(17)
    AGE_RANGE_45_54 = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(503004)
    AGE_RANGE_45_64 = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(18)
    AGE_RANGE_45_65_UP = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(19)
    AGE_RANGE_50_65_UP = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(20)
    AGE_RANGE_55_64 = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(503005)
    AGE_RANGE_55_65_UP = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(21)
    AGE_RANGE_65_UP = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(503006)
    def __init__(
        self,
    ) -> None: ...

global___ReachPlanAgeRangeEnum = ReachPlanAgeRangeEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class CustomerPayPerConversionEligibilityFailureReasonEnum(
    google.protobuf.message.Message
):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _CustomerPayPerConversionEligibilityFailureReason(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            CustomerPayPerConversionEligibilityFailureReason.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = CustomerPayPerConversionEligibilityFailureReasonEnum.CustomerPayPerConversionEligibilityFailureReason.V(
            0
        )
        UNKNOWN = CustomerPayPerConversionEligibilityFailureReasonEnum.CustomerPayPerConversionEligibilityFailureReason.V(
            1
        )
        NOT_ENOUGH_CONVERSIONS = CustomerPayPerConversionEligibilityFailureReasonEnum.CustomerPayPerConversionEligibilityFailureReason.V(
            2
        )
        CONVERSION_LAG_TOO_HIGH = CustomerPayPerConversionEligibilityFailureReasonEnum.CustomerPayPerConversionEligibilityFailureReason.V(
            3
        )
        HAS_CAMPAIGN_WITH_SHARED_BUDGET = CustomerPayPerConversionEligibilityFailureReasonEnum.CustomerPayPerConversionEligibilityFailureReason.V(
            4
        )
        HAS_UPLOAD_CLICKS_CONVERSION = CustomerPayPerConversionEligibilityFailureReasonEnum.CustomerPayPerConversionEligibilityFailureReason.V(
            5
        )
        AVERAGE_DAILY_SPEND_TOO_HIGH = CustomerPayPerConversionEligibilityFailureReasonEnum.CustomerPayPerConversionEligibilityFailureReason.V(
            6
        )
        ANALYSIS_NOT_COMPLETE = CustomerPayPerConversionEligibilityFailureReasonEnum.CustomerPayPerConversionEligibilityFailureReason.V(
            7
        )
        OTHER = CustomerPayPerConversionEligibilityFailureReasonEnum.CustomerPayPerConversionEligibilityFailureReason.V(
            8
        )
    class CustomerPayPerConversionEligibilityFailureReason(
        metaclass=_CustomerPayPerConversionEligibilityFailureReason
    ):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = CustomerPayPerConversionEligibilityFailureReasonEnum.CustomerPayPerConversionEligibilityFailureReason.V(
        0
    )
    UNKNOWN = CustomerPayPerConversionEligibilityFailureReasonEnum.CustomerPayPerConversionEligibilityFailureReason.V(
        1
    )
    NOT_ENOUGH_CONVERSIONS = CustomerPayPerConversionEligibilityFailureReasonEnum.CustomerPayPerConversionEligibilityFailureReason.V(
        2
    )
    CONVERSION_LAG_TOO_HIGH = CustomerPayPerConversionEligibilityFailureReasonEnum.CustomerPayPerConversionEligibilityFailureReason.V(
        3
    )
    HAS_CAMPAIGN_WITH_SHARED_BUDGET = CustomerPayPerConversionEligibilityFailureReasonEnum.CustomerPayPerConversionEligibilityFailureReason.V(
        4
    )
    HAS_UPLOAD_CLICKS_CONVERSION = CustomerPayPerConversionEligibilityFailureReasonEnum.CustomerPayPerConversionEligibilityFailureReason.V(
        5
    )
    AVERAGE_DAILY_SPEND_TOO_HIGH = CustomerPayPerConversionEligibilityFailureReasonEnum.CustomerPayPerConversionEligibilityFailureReason.V(
        6
    )
    ANALYSIS_NOT_COMPLETE = CustomerPayPerConversionEligibilityFailureReasonEnum.CustomerPayPerConversionEligibilityFailureReason.V(
        7
    )
    OTHER = CustomerPayPerConversionEligibilityFailureReasonEnum.CustomerPayPerConversionEligibilityFailureReason.V(
        8
    )
    def __init__(
        self,
    ) -> None: ...

global___CustomerPayPerConversionEligibilityFailureReasonEnum = (
    CustomerPayPerConversionEligibilityFailureReasonEnum
)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v6.proto.enums.shared_set_status_pb2
import google.ads.google_ads.v6.proto.enums.shared_set_type_pb2
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class SharedSet(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    MEMBER_COUNT_FIELD_NUMBER: builtins.int
    REFERENCE_COUNT_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    id: builtins.int = ...
    type: google.ads.google_ads.v6.proto.enums.shared_set_type_pb2.SharedSetTypeEnum.SharedSetType.V = (
        ...
    )
    name: typing.Text = ...
    status: google.ads.google_ads.v6.proto.enums.shared_set_status_pb2.SharedSetStatusEnum.SharedSetStatus.V = (
        ...
    )
    member_count: builtins.int = ...
    reference_count: builtins.int = ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        id: builtins.int = ...,
        type: google.ads.google_ads.v6.proto.enums.shared_set_type_pb2.SharedSetTypeEnum.SharedSetType.V = ...,
        name: typing.Text = ...,
        status: google.ads.google_ads.v6.proto.enums.shared_set_status_pb2.SharedSetStatusEnum.SharedSetStatus.V = ...,
        member_count: builtins.int = ...,
        reference_count: builtins.int = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_id",
            b"_id",
            "_member_count",
            b"_member_count",
            "_name",
            b"_name",
            "_reference_count",
            b"_reference_count",
            "id",
            b"id",
            "member_count",
            b"member_count",
            "name",
            b"name",
            "reference_count",
            b"reference_count",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_id",
            b"_id",
            "_member_count",
            b"_member_count",
            "_name",
            b"_name",
            "_reference_count",
            b"_reference_count",
            "id",
            b"id",
            "member_count",
            b"member_count",
            "name",
            b"name",
            "reference_count",
            b"reference_count",
            "resource_name",
            b"resource_name",
            "status",
            b"status",
            "type",
            b"type",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_id", b"_id"]
    ) -> typing_extensions.Literal["id"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_member_count", b"_member_count"]
    ) -> typing_extensions.Literal["member_count"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_name", b"_name"]
    ) -> typing_extensions.Literal["name"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_reference_count", b"_reference_count"],
    ) -> typing_extensions.Literal["reference_count"]: ...

global___SharedSet = SharedSet



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class Video(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    CHANNEL_ID_FIELD_NUMBER: builtins.int
    DURATION_MILLIS_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    @property
    def id(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def channel_id(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def duration_millis(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def title(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        id: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        channel_id: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        duration_millis: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        title: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "channel_id",
            b"channel_id",
            "duration_millis",
            b"duration_millis",
            "id",
            b"id",
            "title",
            b"title",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "channel_id",
            b"channel_id",
            "duration_millis",
            b"duration_millis",
            "id",
            b"id",
            "resource_name",
            b"resource_name",
            "title",
            b"title",
        ],
    ) -> None: ...

global___Video = Video



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class DeviceEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _Device(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Device.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = DeviceEnum.Device.V(0)
        UNKNOWN = DeviceEnum.Device.V(1)
        MOBILE = DeviceEnum.Device.V(2)
        TABLET = DeviceEnum.Device.V(3)
        DESKTOP = DeviceEnum.Device.V(4)
        CONNECTED_TV = DeviceEnum.Device.V(6)
        OTHER = DeviceEnum.Device.V(5)
    class Device(metaclass=_Device):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = DeviceEnum.Device.V(0)
    UNKNOWN = DeviceEnum.Device.V(1)
    MOBILE = DeviceEnum.Device.V(2)
    TABLET = DeviceEnum.Device.V(3)
    DESKTOP = DeviceEnum.Device.V(4)
    CONNECTED_TV = DeviceEnum.Device.V(6)
    OTHER = DeviceEnum.Device.V(5)
    def __init__(
        self,
    ) -> None: ...

global___DeviceEnum = DeviceEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class PlaceholderTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _PlaceholderType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[PlaceholderType.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = PlaceholderTypeEnum.PlaceholderType.V(0)
        UNKNOWN = PlaceholderTypeEnum.PlaceholderType.V(1)
        SITELINK = PlaceholderTypeEnum.PlaceholderType.V(2)
        CALL = PlaceholderTypeEnum.PlaceholderType.V(3)
        APP = PlaceholderTypeEnum.PlaceholderType.V(4)
        LOCATION = PlaceholderTypeEnum.PlaceholderType.V(5)
        AFFILIATE_LOCATION = PlaceholderTypeEnum.PlaceholderType.V(6)
        CALLOUT = PlaceholderTypeEnum.PlaceholderType.V(7)
        STRUCTURED_SNIPPET = PlaceholderTypeEnum.PlaceholderType.V(8)
        MESSAGE = PlaceholderTypeEnum.PlaceholderType.V(9)
        PRICE = PlaceholderTypeEnum.PlaceholderType.V(10)
        PROMOTION = PlaceholderTypeEnum.PlaceholderType.V(11)
        AD_CUSTOMIZER = PlaceholderTypeEnum.PlaceholderType.V(12)
        DYNAMIC_EDUCATION = PlaceholderTypeEnum.PlaceholderType.V(13)
        DYNAMIC_FLIGHT = PlaceholderTypeEnum.PlaceholderType.V(14)
        DYNAMIC_CUSTOM = PlaceholderTypeEnum.PlaceholderType.V(15)
        DYNAMIC_HOTEL = PlaceholderTypeEnum.PlaceholderType.V(16)
        DYNAMIC_REAL_ESTATE = PlaceholderTypeEnum.PlaceholderType.V(17)
        DYNAMIC_TRAVEL = PlaceholderTypeEnum.PlaceholderType.V(18)
        DYNAMIC_LOCAL = PlaceholderTypeEnum.PlaceholderType.V(19)
        DYNAMIC_JOB = PlaceholderTypeEnum.PlaceholderType.V(20)
    class PlaceholderType(metaclass=_PlaceholderType):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = PlaceholderTypeEnum.PlaceholderType.V(0)
    UNKNOWN = PlaceholderTypeEnum.PlaceholderType.V(1)
    SITELINK = PlaceholderTypeEnum.PlaceholderType.V(2)
    CALL = PlaceholderTypeEnum.PlaceholderType.V(3)
    APP = PlaceholderTypeEnum.PlaceholderType.V(4)
    LOCATION = PlaceholderTypeEnum.PlaceholderType.V(5)
    AFFILIATE_LOCATION = PlaceholderTypeEnum.PlaceholderType.V(6)
    CALLOUT = PlaceholderTypeEnum.PlaceholderType.V(7)
    STRUCTURED_SNIPPET = PlaceholderTypeEnum.PlaceholderType.V(8)
    MESSAGE = PlaceholderTypeEnum.PlaceholderType.V(9)
    PRICE = PlaceholderTypeEnum.PlaceholderType.V(10)
    PROMOTION = PlaceholderTypeEnum.PlaceholderType.V(11)
    AD_CUSTOMIZER = PlaceholderTypeEnum.PlaceholderType.V(12)
    DYNAMIC_EDUCATION = PlaceholderTypeEnum.PlaceholderType.V(13)
    DYNAMIC_FLIGHT = PlaceholderTypeEnum.PlaceholderType.V(14)
    DYNAMIC_CUSTOM = PlaceholderTypeEnum.PlaceholderType.V(15)
    DYNAMIC_HOTEL = PlaceholderTypeEnum.PlaceholderType.V(16)
    DYNAMIC_REAL_ESTATE = PlaceholderTypeEnum.PlaceholderType.V(17)
    DYNAMIC_TRAVEL = PlaceholderTypeEnum.PlaceholderType.V(18)
    DYNAMIC_LOCAL = PlaceholderTypeEnum.PlaceholderType.V(19)
    DYNAMIC_JOB = PlaceholderTypeEnum.PlaceholderType.V(20)
    def __init__(
        self,
    ) -> None: ...

global___PlaceholderTypeEnum = PlaceholderTypeEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class RealEstatePlaceholderFieldEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _RealEstatePlaceholderField(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            RealEstatePlaceholderField.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = RealEstatePlaceholderFieldEnum.RealEstatePlaceholderField.V(0)
        UNKNOWN = RealEstatePlaceholderFieldEnum.RealEstatePlaceholderField.V(1)
        LISTING_ID = RealEstatePlaceholderFieldEnum.RealEstatePlaceholderField.V(2)
        LISTING_NAME = RealEstatePlaceholderFieldEnum.RealEstatePlaceholderField.V(3)
        CITY_NAME = RealEstatePlaceholderFieldEnum.RealEstatePlaceholderField.V(4)
        DESCRIPTION = RealEstatePlaceholderFieldEnum.RealEstatePlaceholderField.V(5)
        ADDRESS = RealEstatePlaceholderFieldEnum.RealEstatePlaceholderField.V(6)
        PRICE = RealEstatePlaceholderFieldEnum.RealEstatePlaceholderField.V(7)
        FORMATTED_PRICE = RealEstatePlaceholderFieldEnum.RealEstatePlaceholderField.V(8)
        IMAGE_URL = RealEstatePlaceholderFieldEnum.RealEstatePlaceholderField.V(9)
        PROPERTY_TYPE = RealEstatePlaceholderFieldEnum.RealEstatePlaceholderField.V(10)
        LISTING_TYPE = RealEstatePlaceholderFieldEnum.RealEstatePlaceholderField.V(11)
        CONTEXTUAL_KEYWORDS = (
            RealEstatePlaceholderFieldEnum.RealEstatePlaceholderField.V(12)
        )
        FINAL_URLS = RealEstatePlaceholderFieldEnum.RealEstatePlaceholderField.V(13)
        FINAL_MOBILE_URLS = RealEstatePlaceholderFieldEnum.RealEstatePlaceholderField.V(
            14
        )
        TRACKING_URL = RealEstatePlaceholderFieldEnum.RealEstatePlaceholderField.V(15)
        ANDROID_APP_LINK = RealEstatePlaceholderFieldEnum.RealEstatePlaceholderField.V(
            16
        )
        SIMILAR_LISTING_IDS = (
            RealEstatePlaceholderFieldEnum.RealEstatePlaceholderField.V(17)
        )
        IOS_APP_LINK = RealEstatePlaceholderFieldEnum.RealEstatePlaceholderField.V(18)
        IOS_APP_STORE_ID = RealEstatePlaceholderFieldEnum.RealEstatePlaceholderField.V(
            19
        )
    class RealEstatePlaceholderField(metaclass=_RealEstatePlaceholderField):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = RealEstatePlaceholderFieldEnum.RealEstatePlaceholderField.V(0)
    UNKNOWN = RealEstatePlaceholderFieldEnum.RealEstatePlaceholderField.V(1)
    LISTING_ID = RealEstatePlaceholderFieldEnum.RealEstatePlaceholderField.V(2)
    LISTING_NAME = RealEstatePlaceholderFieldEnum.RealEstatePlaceholderField.V(3)
    CITY_NAME = RealEstatePlaceholderFieldEnum.RealEstatePlaceholderField.V(4)
    DESCRIPTION = RealEstatePlaceholderFieldEnum.RealEstatePlaceholderField.V(5)
    ADDRESS = RealEstatePlaceholderFieldEnum.RealEstatePlaceholderField.V(6)
    PRICE = RealEstatePlaceholderFieldEnum.RealEstatePlaceholderField.V(7)
    FORMATTED_PRICE = RealEstatePlaceholderFieldEnum.RealEstatePlaceholderField.V(8)
    IMAGE_URL = RealEstatePlaceholderFieldEnum.RealEstatePlaceholderField.V(9)
    PROPERTY_TYPE = RealEstatePlaceholderFieldEnum.RealEstatePlaceholderField.V(10)
    LISTING_TYPE = RealEstatePlaceholderFieldEnum.RealEstatePlaceholderField.V(11)
    CONTEXTUAL_KEYWORDS = RealEstatePlaceholderFieldEnum.RealEstatePlaceholderField.V(
        12
    )
    FINAL_URLS = RealEstatePlaceholderFieldEnum.RealEstatePlaceholderField.V(13)
    FINAL_MOBILE_URLS = RealEstatePlaceholderFieldEnum.RealEstatePlaceholderField.V(14)
    TRACKING_URL = RealEstatePlaceholderFieldEnum.RealEstatePlaceholderField.V(15)
    ANDROID_APP_LINK = RealEstatePlaceholderFieldEnum.RealEstatePlaceholderField.V(16)
    SIMILAR_LISTING_IDS = RealEstatePlaceholderFieldEnum.RealEstatePlaceholderField.V(
        17
    )
    IOS_APP_LINK = RealEstatePlaceholderFieldEnum.RealEstatePlaceholderField.V(18)
    IOS_APP_STORE_ID = RealEstatePlaceholderFieldEnum.RealEstatePlaceholderField.V(19)
    def __init__(
        self,
    ) -> None: ...

global___RealEstatePlaceholderFieldEnum = RealEstatePlaceholderFieldEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class DomainCategory(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    CAMPAIGN_FIELD_NUMBER: builtins.int
    CATEGORY_FIELD_NUMBER: builtins.int
    LANGUAGE_CODE_FIELD_NUMBER: builtins.int
    DOMAIN_FIELD_NUMBER: builtins.int
    COVERAGE_FRACTION_FIELD_NUMBER: builtins.int
    CATEGORY_RANK_FIELD_NUMBER: builtins.int
    HAS_CHILDREN_FIELD_NUMBER: builtins.int
    RECOMMENDED_CPC_BID_MICROS_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    campaign: typing.Text = ...
    category: typing.Text = ...
    language_code: typing.Text = ...
    domain: typing.Text = ...
    coverage_fraction: builtins.float = ...
    category_rank: builtins.int = ...
    has_children: builtins.bool = ...
    recommended_cpc_bid_micros: builtins.int = ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        campaign: typing.Text = ...,
        category: typing.Text = ...,
        language_code: typing.Text = ...,
        domain: typing.Text = ...,
        coverage_fraction: builtins.float = ...,
        category_rank: builtins.int = ...,
        has_children: builtins.bool = ...,
        recommended_cpc_bid_micros: builtins.int = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_campaign",
            b"_campaign",
            "_category",
            b"_category",
            "_category_rank",
            b"_category_rank",
            "_coverage_fraction",
            b"_coverage_fraction",
            "_domain",
            b"_domain",
            "_has_children",
            b"_has_children",
            "_language_code",
            b"_language_code",
            "_recommended_cpc_bid_micros",
            b"_recommended_cpc_bid_micros",
            "campaign",
            b"campaign",
            "category",
            b"category",
            "category_rank",
            b"category_rank",
            "coverage_fraction",
            b"coverage_fraction",
            "domain",
            b"domain",
            "has_children",
            b"has_children",
            "language_code",
            b"language_code",
            "recommended_cpc_bid_micros",
            b"recommended_cpc_bid_micros",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_campaign",
            b"_campaign",
            "_category",
            b"_category",
            "_category_rank",
            b"_category_rank",
            "_coverage_fraction",
            b"_coverage_fraction",
            "_domain",
            b"_domain",
            "_has_children",
            b"_has_children",
            "_language_code",
            b"_language_code",
            "_recommended_cpc_bid_micros",
            b"_recommended_cpc_bid_micros",
            "campaign",
            b"campaign",
            "category",
            b"category",
            "category_rank",
            b"category_rank",
            "coverage_fraction",
            b"coverage_fraction",
            "domain",
            b"domain",
            "has_children",
            b"has_children",
            "language_code",
            b"language_code",
            "recommended_cpc_bid_micros",
            b"recommended_cpc_bid_micros",
            "resource_name",
            b"resource_name",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_campaign", b"_campaign"]
    ) -> typing_extensions.Literal["campaign"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_category", b"_category"]
    ) -> typing_extensions.Literal["category"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_category_rank", b"_category_rank"],
    ) -> typing_extensions.Literal["category_rank"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_coverage_fraction", b"_coverage_fraction"
        ],
    ) -> typing_extensions.Literal["coverage_fraction"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_domain", b"_domain"]
    ) -> typing_extensions.Literal["domain"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_has_children", b"_has_children"]
    ) -> typing_extensions.Literal["has_children"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_language_code", b"_language_code"],
    ) -> typing_extensions.Literal["language_code"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_recommended_cpc_bid_micros", b"_recommended_cpc_bid_micros"
        ],
    ) -> typing_extensions.Literal["recommended_cpc_bid_micros"]: ...

global___DomainCategory = DomainCategory



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class ExpandedLandingPageView(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    EXPANDED_FINAL_URL_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    expanded_final_url: typing.Text = ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        expanded_final_url: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_expanded_final_url",
            b"_expanded_final_url",
            "expanded_final_url",
            b"expanded_final_url",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_expanded_final_url",
            b"_expanded_final_url",
            "expanded_final_url",
            b"expanded_final_url",
            "resource_name",
            b"resource_name",
        ],
    ) -> None: ...
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_expanded_final_url", b"_expanded_final_url"
        ],
    ) -> typing_extensions.Literal["expanded_final_url"]: ...

global___ExpandedLandingPageView = ExpandedLandingPageView



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class ImageErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _ImageError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ImageError.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = ImageErrorEnum.ImageError.V(0)
        UNKNOWN = ImageErrorEnum.ImageError.V(1)
        INVALID_IMAGE = ImageErrorEnum.ImageError.V(2)
        STORAGE_ERROR = ImageErrorEnum.ImageError.V(3)
        BAD_REQUEST = ImageErrorEnum.ImageError.V(4)
        UNEXPECTED_SIZE = ImageErrorEnum.ImageError.V(5)
        ANIMATED_NOT_ALLOWED = ImageErrorEnum.ImageError.V(6)
        ANIMATION_TOO_LONG = ImageErrorEnum.ImageError.V(7)
        SERVER_ERROR = ImageErrorEnum.ImageError.V(8)
        CMYK_JPEG_NOT_ALLOWED = ImageErrorEnum.ImageError.V(9)
        FLASH_NOT_ALLOWED = ImageErrorEnum.ImageError.V(10)
        FLASH_WITHOUT_CLICKTAG = ImageErrorEnum.ImageError.V(11)
        FLASH_ERROR_AFTER_FIXING_CLICK_TAG = ImageErrorEnum.ImageError.V(12)
        ANIMATED_VISUAL_EFFECT = ImageErrorEnum.ImageError.V(13)
        FLASH_ERROR = ImageErrorEnum.ImageError.V(14)
        LAYOUT_PROBLEM = ImageErrorEnum.ImageError.V(15)
        PROBLEM_READING_IMAGE_FILE = ImageErrorEnum.ImageError.V(16)
        ERROR_STORING_IMAGE = ImageErrorEnum.ImageError.V(17)
        ASPECT_RATIO_NOT_ALLOWED = ImageErrorEnum.ImageError.V(18)
        FLASH_HAS_NETWORK_OBJECTS = ImageErrorEnum.ImageError.V(19)
        FLASH_HAS_NETWORK_METHODS = ImageErrorEnum.ImageError.V(20)
        FLASH_HAS_URL = ImageErrorEnum.ImageError.V(21)
        FLASH_HAS_MOUSE_TRACKING = ImageErrorEnum.ImageError.V(22)
        FLASH_HAS_RANDOM_NUM = ImageErrorEnum.ImageError.V(23)
        FLASH_SELF_TARGETS = ImageErrorEnum.ImageError.V(24)
        FLASH_BAD_GETURL_TARGET = ImageErrorEnum.ImageError.V(25)
        FLASH_VERSION_NOT_SUPPORTED = ImageErrorEnum.ImageError.V(26)
        FLASH_WITHOUT_HARD_CODED_CLICK_URL = ImageErrorEnum.ImageError.V(27)
        INVALID_FLASH_FILE = ImageErrorEnum.ImageError.V(28)
        FAILED_TO_FIX_CLICK_TAG_IN_FLASH = ImageErrorEnum.ImageError.V(29)
        FLASH_ACCESSES_NETWORK_RESOURCES = ImageErrorEnum.ImageError.V(30)
        FLASH_EXTERNAL_JS_CALL = ImageErrorEnum.ImageError.V(31)
        FLASH_EXTERNAL_FS_CALL = ImageErrorEnum.ImageError.V(32)
        FILE_TOO_LARGE = ImageErrorEnum.ImageError.V(33)
        IMAGE_DATA_TOO_LARGE = ImageErrorEnum.ImageError.V(34)
        IMAGE_PROCESSING_ERROR = ImageErrorEnum.ImageError.V(35)
        IMAGE_TOO_SMALL = ImageErrorEnum.ImageError.V(36)
        INVALID_INPUT = ImageErrorEnum.ImageError.V(37)
        PROBLEM_READING_FILE = ImageErrorEnum.ImageError.V(38)
        IMAGE_CONSTRAINTS_VIOLATED = ImageErrorEnum.ImageError.V(39)
    class ImageError(metaclass=_ImageError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = ImageErrorEnum.ImageError.V(0)
    UNKNOWN = ImageErrorEnum.ImageError.V(1)
    INVALID_IMAGE = ImageErrorEnum.ImageError.V(2)
    STORAGE_ERROR = ImageErrorEnum.ImageError.V(3)
    BAD_REQUEST = ImageErrorEnum.ImageError.V(4)
    UNEXPECTED_SIZE = ImageErrorEnum.ImageError.V(5)
    ANIMATED_NOT_ALLOWED = ImageErrorEnum.ImageError.V(6)
    ANIMATION_TOO_LONG = ImageErrorEnum.ImageError.V(7)
    SERVER_ERROR = ImageErrorEnum.ImageError.V(8)
    CMYK_JPEG_NOT_ALLOWED = ImageErrorEnum.ImageError.V(9)
    FLASH_NOT_ALLOWED = ImageErrorEnum.ImageError.V(10)
    FLASH_WITHOUT_CLICKTAG = ImageErrorEnum.ImageError.V(11)
    FLASH_ERROR_AFTER_FIXING_CLICK_TAG = ImageErrorEnum.ImageError.V(12)
    ANIMATED_VISUAL_EFFECT = ImageErrorEnum.ImageError.V(13)
    FLASH_ERROR = ImageErrorEnum.ImageError.V(14)
    LAYOUT_PROBLEM = ImageErrorEnum.ImageError.V(15)
    PROBLEM_READING_IMAGE_FILE = ImageErrorEnum.ImageError.V(16)
    ERROR_STORING_IMAGE = ImageErrorEnum.ImageError.V(17)
    ASPECT_RATIO_NOT_ALLOWED = ImageErrorEnum.ImageError.V(18)
    FLASH_HAS_NETWORK_OBJECTS = ImageErrorEnum.ImageError.V(19)
    FLASH_HAS_NETWORK_METHODS = ImageErrorEnum.ImageError.V(20)
    FLASH_HAS_URL = ImageErrorEnum.ImageError.V(21)
    FLASH_HAS_MOUSE_TRACKING = ImageErrorEnum.ImageError.V(22)
    FLASH_HAS_RANDOM_NUM = ImageErrorEnum.ImageError.V(23)
    FLASH_SELF_TARGETS = ImageErrorEnum.ImageError.V(24)
    FLASH_BAD_GETURL_TARGET = ImageErrorEnum.ImageError.V(25)
    FLASH_VERSION_NOT_SUPPORTED = ImageErrorEnum.ImageError.V(26)
    FLASH_WITHOUT_HARD_CODED_CLICK_URL = ImageErrorEnum.ImageError.V(27)
    INVALID_FLASH_FILE = ImageErrorEnum.ImageError.V(28)
    FAILED_TO_FIX_CLICK_TAG_IN_FLASH = ImageErrorEnum.ImageError.V(29)
    FLASH_ACCESSES_NETWORK_RESOURCES = ImageErrorEnum.ImageError.V(30)
    FLASH_EXTERNAL_JS_CALL = ImageErrorEnum.ImageError.V(31)
    FLASH_EXTERNAL_FS_CALL = ImageErrorEnum.ImageError.V(32)
    FILE_TOO_LARGE = ImageErrorEnum.ImageError.V(33)
    IMAGE_DATA_TOO_LARGE = ImageErrorEnum.ImageError.V(34)
    IMAGE_PROCESSING_ERROR = ImageErrorEnum.ImageError.V(35)
    IMAGE_TOO_SMALL = ImageErrorEnum.ImageError.V(36)
    INVALID_INPUT = ImageErrorEnum.ImageError.V(37)
    PROBLEM_READING_FILE = ImageErrorEnum.ImageError.V(38)
    IMAGE_CONSTRAINTS_VIOLATED = ImageErrorEnum.ImageError.V(39)
    def __init__(
        self,
    ) -> None: ...

global___ImageErrorEnum = ImageErrorEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class SearchTermTargetingStatusEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _SearchTermTargetingStatus(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            SearchTermTargetingStatus.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = SearchTermTargetingStatusEnum.SearchTermTargetingStatus.V(0)
        UNKNOWN = SearchTermTargetingStatusEnum.SearchTermTargetingStatus.V(1)
        ADDED = SearchTermTargetingStatusEnum.SearchTermTargetingStatus.V(2)
        EXCLUDED = SearchTermTargetingStatusEnum.SearchTermTargetingStatus.V(3)
        ADDED_EXCLUDED = SearchTermTargetingStatusEnum.SearchTermTargetingStatus.V(4)
        NONE = SearchTermTargetingStatusEnum.SearchTermTargetingStatus.V(5)
    class SearchTermTargetingStatus(metaclass=_SearchTermTargetingStatus):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = SearchTermTargetingStatusEnum.SearchTermTargetingStatus.V(0)
    UNKNOWN = SearchTermTargetingStatusEnum.SearchTermTargetingStatus.V(1)
    ADDED = SearchTermTargetingStatusEnum.SearchTermTargetingStatus.V(2)
    EXCLUDED = SearchTermTargetingStatusEnum.SearchTermTargetingStatus.V(3)
    ADDED_EXCLUDED = SearchTermTargetingStatusEnum.SearchTermTargetingStatus.V(4)
    NONE = SearchTermTargetingStatusEnum.SearchTermTargetingStatus.V(5)
    def __init__(
        self,
    ) -> None: ...

global___SearchTermTargetingStatusEnum = SearchTermTargetingStatusEnum
